Crate temporalio_client

Crate temporalio_client 

This crate contains client implementations that can be used to contact the Temporal service.

It implements auto-retry behavior and metrics collection.

Re-exports

pub use tonic;

Modules

callback_based
This module implements support for callback-based gRPC service that has a callback invoked for every gRPC call instead of directly using the network.
client_options_builder
Tools for manipulating the type state of ClientOptionsBuilder.
connection_options_builder
Tools for manipulating the type state of ConnectionOptionsBuilder.
errors
Contains errors that can be returned by clients.
grpc
gRPC service traits for direct access to Temporal services.
request_extensions
Request extensions for tonic gRPC requests.
worker
Contains types and logic for interactions between clients and Core/SDK workers

Structs

ActivityHeartbeatResponse
Response from a heartbeat call.
AsyncActivityHandle
Handle for completing activities asynchronously (outside the worker).
Client
Contains an instance of a namespace-bound client for interacting with the Temporal server. Cheap to clone.
ClientKeepAliveOptions
Client keep alive configuration.
ClientOptions
Options for crate::Client::new.
ClientOptionsBuilder
Use builder syntax to set the inputs and finish with build().
ClientTlsOptions
If using mTLS, both the client cert and private key must be specified, this contains them.
Connection
A connection to the Temporal service.
ConnectionOptions
Options for crate::Connection::connect.
ConnectionOptionsBuilder
Use builder syntax to set the inputs and finish with build().
HttpConnectProxyOptions
Options for HTTP CONNECT proxy.
ListWorkflowsStream
A stream of workflow executions from a list query. Internally paginates through results from the server.
Priority
Priority contains metadata that controls relative ordering of task processing when tasks are backlogged in a queue. Initially, Priority will be used in activity and workflow task queues, which are typically where backlogs exist. Other queues in the server (such as transfer and timer queues) and rate limiting decisions do not use Priority, but may in the future.
RegisterNamespaceOptions
Helper struct for register_namespace.
RegisterNamespaceOptionsBuilder
Use builder syntax to set the inputs and finish with build().
RetryOptions
Configuration for retrying requests to the server
ServiceCallInterceptor
Interceptor which attaches common metadata (like “client-name”) to every outgoing call
SharedReplaceableClient
A client wrapper that allows replacing the underlying client at a later point in time. Clones of this struct have a shared reference to the underlying client, and each clone also has its own cached clone of the underlying client. Before every service call, a check is made whether the shared client was replaced, and the cached clone is updated accordingly.
TemporalServiceClient
Aggregates various services exposed by the Temporal server
TlsOptions
Configuration options for TLS
UntypedQuery
Marker type for sending untyped queries. Stores the query name for runtime lookup.
UntypedSignal
Marker type for sending untyped signals. Stores the signal name for runtime lookup.
UntypedUpdate
Marker type for sending untyped updates. Stores the update name for runtime lookup.
UntypedWorkflow
Marker type for untyped workflow handles. Stores the workflow type name.
WorkflowCancelOptions
Options for cancelling a workflow.
WorkflowCancelOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowCountAggregationGroup
Aggregation group from a workflow count query with a group-by clause.
WorkflowCountOptions
Options for counting workflows.
WorkflowCountOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowDescribeOptions
Options for describing a workflow.
WorkflowDescribeOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowExecuteUpdateOptions
Options for starting a workflow update.
WorkflowExecuteUpdateOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowExecution
A workflow execution returned from list operations. This represents information about a workflow present in visibility.
WorkflowExecutionCount
Result of a workflow count operation.
WorkflowExecutionDescription
Description of a workflow execution returned by WorkflowHandle::describe.
WorkflowExecutionInfo
Holds needed information to refer to a specific workflow run, or workflow execution chain
WorkflowFetchHistoryOptions
Options for fetching workflow history.
WorkflowFetchHistoryOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowGetResultOptions
Options for fetching workflow results
WorkflowGetResultOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowHandle
A workflow handle which can refer to a specific workflow run, or a chain of workflow runs with the same workflow id.
WorkflowHistory
Workflow execution history returned by WorkflowHandle::fetch_history.
WorkflowListOptions
Options for listing workflows.
WorkflowListOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowQueryOptions
Options for querying a workflow.
WorkflowQueryOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowSignalOptions
Options for sending a signal to a workflow.
WorkflowSignalOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowStartOptions
Options for starting a workflow execution.
WorkflowStartOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowStartSignal
A signal to send atomically when starting a workflow. Use with WorkflowStartOptions::start_signal to achieve signal-with-start behavior.
WorkflowStartSignalBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowStartUpdateOptions
Options for starting an update without waiting for completion.
WorkflowStartUpdateOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowTerminateOptions
Options for terminating a workflow.
WorkflowTerminateOptionsBuilder
Use builder syntax to set the inputs and finish with build().
WorkflowUpdateHandle
Handle to a workflow update that has been started but may not be complete.

Enums

ActivityIdentifier
Identifies an async activity for completion outside a worker.
Namespace
Enum to help reference a namespace by either the namespace name or the namespace id
WorkflowExecutionResult
Enumerates terminal states for a particular workflow execution
WorkflowUpdateWaitStage
Which lifecycle stage to wait for when starting an update.

Statics

LONG_REQUEST_LATENCY_HISTOGRAM_NAME
The string name (which may be prefixed) for this metric
REQUEST_LATENCY_HISTOGRAM_NAME
The string name (which may be prefixed) for this metric

Traits

NamespacedClient
A client that is bound to a namespace

Type Aliases

UntypedWorkflowHandle
A workflow handle to a workflow with unknown types. Uses single argument raw payloads for input and output.