Module callback_based

Module callback_based 

This module implements support for callback-based gRPC service that has a callback invoked for every gRPC call instead of directly using the network.

Structs

CallbackBasedGrpcService
gRPC service that invokes the given callback on each call.
GrpcRequest
gRPC request for use by a callback.
GrpcSuccessResponse
Successful gRPC response returned by a callback.