Tools for manipulating the type state of ConnectionOptionsBuilder.
See the detailed guide that describes how all the pieces here fit together.
Structs
- Empty
- Represents a
Statethat hasIsUnsetimplemented for all members. - SetApi
Key - Represents a
Statethat hasIsSetimplemented forState::ApiKey. - SetBinary
Headers - Represents a
Statethat hasIsSetimplemented forState::BinaryHeaders. - SetClient
Name - Represents a
Statethat hasIsSetimplemented forState::ClientName. - SetClient
Version - Represents a
Statethat hasIsSetimplemented forState::ClientVersion. - SetDisable
Error Code Metric Tags - Represents a
Statethat hasIsSetimplemented forState::DisableErrorCodeMetricTags. - SetHeaders
- Represents a
Statethat hasIsSetimplemented forState::Headers. - SetHttp
Connect Proxy - Represents a
Statethat hasIsSetimplemented forState::HttpConnectProxy. - SetIdentity
- Represents a
Statethat hasIsSetimplemented forState::Identity. - SetKeep
Alive - Represents a
Statethat hasIsSetimplemented forState::KeepAlive. - SetMetrics
Meter - Represents a
Statethat hasIsSetimplemented forState::MetricsMeter. - SetOverride
Origin - Represents a
Statethat hasIsSetimplemented forState::OverrideOrigin. - SetRetry
Options - Represents a
Statethat hasIsSetimplemented forState::RetryOptions. - SetService
Override - Represents a
Statethat hasIsSetimplemented forState::ServiceOverride. - SetSkip
GetSystem Info - Represents a
Statethat hasIsSetimplemented forState::SkipGetSystemInfo. - SetTls
Options - Represents a
Statethat hasIsSetimplemented forState::TlsOptions.
Traits
- IsComplete
- Marker trait that indicates that all required members are set.
- IsSet
- Marker trait that indicates that the member is set, i.e. at least one of its setters was called.
- IsUnset
- Marker trait that indicates that the member is unset, i.e. none of its setters was called.
- State
- Builder’s type state specifies if members are set or not (unset).