Module danger

Module danger 

Potentially dangerous TLS related functionality.

Traits

ServerCertVerifier
Re-export the ServerCertVerifier trait so that users can implement custom TLS server certificate verification without depending on tokio-rustls directly, while explicitly acknowledging the danger in the import path. Something that can verify a server certificate chain, and verify signatures made by certificates.