ActivityExecutionStatus

Enum ActivityExecutionStatus 

#[non_exhaustive]
pub enum ActivityExecutionStatus { Unspecified, Running, Completed, Failed, Canceled, Terminated, TimedOut, Paused, Unknown, }
Execution status of an activity. See ActivityExecutionInfoLike::status.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspecified

This variant indicates the server did not specify a value.



Running

The activity has not reached a terminal status. See ActivityExecutionDescription::run_state for the run state.



Completed

The activity completed successfully.



Failed

The activity failed with an error.



Canceled

The activity was canceled. Note that cancellation is cooperative and a cancel request does not always result in canceled status.



Terminated

The activity was terminated.



TimedOut

The activity timed out.



Paused

The activity is paused.



Unknown

This variant indicates the server used a value not known by this version of the SDK.