#[non_exhaustive]pub enum ActivityIdReusePolicy {
AllowDuplicate,
AllowDuplicateFailedOnly,
RejectDuplicate,
}Expand description
Specifies behavior when starting a standalone activity if there’s a closed activity with
the same ID. See ActivityStartOptions::id_reuse_policy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AllowDuplicate
Always allow starting an activity using the same activity ID. This is the default.
AllowDuplicateFailedOnly
Allow starting an activity using the same ID only when the last execution did not complete successfully.
RejectDuplicate
Do not permit re-use of the ID for this activity.