#[non_exhaustive]pub enum PendingActivityState {
Unspecified,
Scheduled,
Started,
CancelRequested,
Paused,
PauseRequested,
Unknown,
}Expand description
Detailed state of an activity with ActivityExecutionStatus::Running.
See ActivityExecutionDescription::run_state.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
This variant indicates the server did not specify a state.
Scheduled
Activity is scheduled for execution but not yet running on a worker.
Started
Activity is running on a worker.
CancelRequested
Activity has been requested to cancel.
Paused
Activity is paused on the server, and is not running on a worker.
PauseRequested
Activity is currently running on a worker, but paused on the server.
Unknown
This variant indicates the server used a value not known by this version of the SDK.