#[non_exhaustive]pub enum QueryRejectCondition {
Unspecified,
None,
NotOpen,
NotCompletedCleanly,
}Expand description
Controls when a workflow query should be rejected based on workflow state.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Use the server’s default condition.
None
Do not reject the query based on workflow state.
NotOpen
Reject the query if the workflow is not open.
NotCompletedCleanly
Reject the query if the workflow did not complete successfully.