pub enum WorkflowUpdateWaitStage {
Admitted,
Accepted,
Completed,
}Expand description
Which lifecycle stage to wait for when starting an update.
Variants
Admitted
This stage is reached when the server receives the update to process. This is currently an invalid value on start.
Accepted
Wait until the update is accepted by the workflow (validator passed).
Completed
Wait until the update has completed.