#[non_exhaustive]pub struct LoadClientConfigProfileOptions {
pub config_source: Option<DataSource>,
pub config_file_profile: Option<String>,
pub config_file_strict: bool,
pub disable_file: bool,
pub disable_env: bool,
}Expand description
Options for loading a client configuration profile
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.config_source: Option<DataSource>Where to load config from. If unset, will try env vars then default path.
config_file_profile: Option<String>Specific profile to use
config_file_strict: boolIf true, will error if there are unrecognized keys.
disable_file: boolDisable loading from file
disable_env: boolDisable loading from environment variables
Implementations
Sourceimpl LoadClientConfigProfileOptions
impl LoadClientConfigProfileOptions
Sourcepub fn builder() -> LoadClientConfigProfileOptionsBuilder
pub fn builder() -> LoadClientConfigProfileOptionsBuilder
Create an instance of LoadClientConfigProfileOptions using the builder syntax