Module errors

Module errors 

Contains errors that can be returned by clients.

Enums

ActivityInteractionError
Errors returned by methods on crate::ActivityHandle that don’t need more specific error types.
ActivityResultError
Errors returned by crate::ActivityHandle::result.
AsyncActivityError
Errors that can occur when completing an activity asynchronously.
ClientConnectError
Errors thrown while attempting to establish a connection to the server
ClientError
Errors returned by client methods that don’t need more specific error types.
ClientNewError
Errors that can occur when constructing a crate::Client.
InvalidHeaderError
Errors thrown when a gRPC metadata header is invalid.
StartActivityError
Errors that can occur when starting a standalone activity.
WorkflowGetResultError
Errors returned by workflow get_result operations.
WorkflowInteractionError
Errors returned by methods on crate::WorkflowHandle for general operations like signal, cancel, terminate, describe, fetch_history, and get_result.
WorkflowQueryError
Errors returned by query operations on crate::WorkflowHandle.
WorkflowStartError
Errors that can occur when starting a workflow.
WorkflowUpdateError
Errors returned by update operations on crate::WorkflowHandle.