#[non_exhaustive]pub enum StartActivityError {
AlreadyStarted {
run_id: String,
source: Status,
},
PayloadConversion(PayloadConversionError),
Rpc(Status),
Other(Box<dyn Error + Send + Sync>),
}Expand description
Errors that can occur when starting a standalone activity.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyStarted
There’s a conflicting activity execution with the same ID according to chosen ID reuse policy and ID conflict policy.
Fields
PayloadConversion(PayloadConversionError)
Error serializing input.
Rpc(Status)
An uncategorized RPC error from the server.
Other(Box<dyn Error + Send + Sync>)
Other errors.