#[non_exhaustive]pub enum WorkflowUpdateWithStartError {
Start(WorkflowStartError),
Update(WorkflowUpdateError),
PayloadConversion(PayloadConversionError),
Rpc(Status),
Other(Box<dyn Error + Send + Sync>),
}Expand description
Errors returned by update-with-start operations (see crate::Client::start_update_with_start_workflow).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Start(WorkflowStartError)
The start operation failed.
Update(WorkflowUpdateError)
The update operation failed, or waiting for the update result failed.
PayloadConversion(PayloadConversionError)
Error serializing the workflow input or update arguments.
Rpc(Status)
An RPC error from the server that could not be attributed to either operation.
Other(Box<dyn Error + Send + Sync>)
Other errors.