Module grpc

Module grpc 

gRPC service traits for direct access to Temporal services.

Most users should use the higher-level methods on Client or Connection instead. These traits are useful for advanced scenarios like custom interceptors, testing with mocks, or making raw gRPC calls not covered by the higher-level API.

Traits

CloudService
Trait version of CloudServiceClient
HealthService
Trait version of HealthClient
OperatorService
Trait version of OperatorServiceClient
TestService
Trait version of TestServiceClient
WorkflowService
Trait version of WorkflowServiceClient