Module interceptors

Module interceptors 

Interceptors for high-level client operations. Interceptors for high-level client operations.

Structs

BackfillScheduleInput
Input to ClientInterceptor::backfill_schedule.
CancelWorkflowInput
Input to ClientInterceptor::cancel_workflow.
CompleteAsyncActivityInput
Input to ClientInterceptor::complete_async_activity.
CountWorkflowsInput
Input to ClientInterceptor::count_workflows.
CountWorkflowsOutput
Result of an intercepted workflow count.
CreateScheduleInput
Input to ClientInterceptor::create_schedule.
CreateScheduleOutput
Result of an intercepted schedule create.
DeleteScheduleInput
Input to ClientInterceptor::delete_schedule.
DescribeScheduleInput
Input to ClientInterceptor::describe_schedule.
DescribeScheduleOutput
Result of an intercepted schedule describe.
DescribeWorkflowInput
Input to ClientInterceptor::describe_workflow.
DescribeWorkflowOutput
Result of an intercepted workflow describe.
FailAsyncActivityInput
Input to ClientInterceptor::fail_async_activity.
FetchWorkflowHistoryPageInput
Input to ClientInterceptor::fetch_workflow_history_page.
FetchWorkflowHistoryPageOutput
Result of one intercepted workflow-history page.
HeartbeatAsyncActivityInput
Input to ClientInterceptor::heartbeat_async_activity.
ListSchedulesPageInput
Input to ClientInterceptor::list_schedules_page.
ListSchedulesPageOutput
Result of one intercepted schedule-list page.
ListWorkflowsPageInput
Input to ClientInterceptor::list_workflows_page.
ListWorkflowsPageOutput
Result of one intercepted workflow-list page.
Next
Continuation for an intercepted client operation.
PauseScheduleInput
Input to ClientInterceptor::pause_schedule.
PollWorkflowUpdateInput
Input to ClientInterceptor::poll_workflow_update.
PollWorkflowUpdateOutput
Result of an intercepted workflow-update poll.
QueryWorkflowInput
Input to ClientInterceptor::query_workflow.
QueryWorkflowOutput
Result of an intercepted workflow query before typed result conversion.
ReportAsyncActivityCancellationInput
Input to ClientInterceptor::report_async_activity_cancellation.
SendScheduleUpdateInput
Input to ClientInterceptor::send_schedule_update.
SignalWorkflowInput
Input to ClientInterceptor::signal_workflow.
StartWorkflowInput
Input to ClientInterceptor::start_workflow.
StartWorkflowOutput
Result of a successful intercepted workflow start.
StartWorkflowUpdateInput
Input to ClientInterceptor::start_workflow_update.
StartWorkflowUpdateOutput
Result of an intercepted workflow-update start.
TerminateWorkflowInput
Input to ClientInterceptor::terminate_workflow.
TriggerScheduleInput
Input to ClientInterceptor::trigger_schedule.
UnpauseScheduleInput
Input to ClientInterceptor::unpause_schedule.
UpdateScheduleInput
Input to ClientInterceptor::update_schedule.

Traits

ClientInterceptor
Intercepts high-level client operations.
HasArgs
Provides access to the arguments carried by a client interceptor input.
TemporalClientValue
Type-erased input carried through the client interceptor chain.