#[non_exhaustive]pub struct CompleteAsyncActivityInput {
pub identifier: ActivityIdentifier,
pub rpc_options: RpcOptions,
/* private fields */
}Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identifier: ActivityIdentifierActivity being completed.
rpc_options: RpcOptionsControls for the completion RPC.
Implementations
Sourceimpl CompleteAsyncActivityInput
impl CompleteAsyncActivityInput
Sourcepub fn result_ref<T: Any>(&self) -> Option<&T>
pub fn result_ref<T: Any>(&self) -> Option<&T>
Attempt to access the activity result as a concrete type.
Sourcepub fn result_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn result_mut<T: Any>(&mut self) -> Option<&mut T>
Attempt to mutably access the activity result as a concrete type.
Sourcepub fn replace_result<T>(&mut self, result: Option<T>)where
T: TemporalSerializable + Send + 'static,
pub fn replace_result<T>(&mut self, result: Option<T>)where
T: TemporalSerializable + Send + 'static,
Replace or clear the activity result.