#[non_exhaustive]pub struct FailAsyncActivityInput {
pub identifier: ActivityIdentifier,
pub failure: ApplicationFailure,
pub rpc_options: RpcOptions,
/* private fields */
}Expand description
Input to ClientInterceptor::fail_async_activity.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identifier: ActivityIdentifierActivity being failed.
failure: ApplicationFailureApplication failure reported for the activity.
rpc_options: RpcOptionsControls for the failure RPC.
Implementations
Sourceimpl FailAsyncActivityInput
impl FailAsyncActivityInput
Sourcepub fn last_heartbeat_details_ref<T: Any>(&self) -> Option<&T>
pub fn last_heartbeat_details_ref<T: Any>(&self) -> Option<&T>
Attempt to access the last heartbeat details as a concrete type.
Sourcepub fn last_heartbeat_details_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn last_heartbeat_details_mut<T: Any>(&mut self) -> Option<&mut T>
Attempt to mutably access the last heartbeat details as a concrete type.
Sourcepub fn replace_last_heartbeat_details<T>(&mut self, details: Option<T>)where
T: TemporalSerializable + Send + 'static,
pub fn replace_last_heartbeat_details<T>(&mut self, details: Option<T>)where
T: TemporalSerializable + Send + 'static,
Replace or clear the last heartbeat details.