#[non_exhaustive]pub struct ReportAsyncActivityCancellationInput {
pub identifier: ActivityIdentifier,
pub rpc_options: RpcOptions,
/* private fields */
}Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identifier: ActivityIdentifierActivity being reported as cancelled.
rpc_options: RpcOptionsControls for the cancellation RPC.
Implementations
Sourceimpl ReportAsyncActivityCancellationInput
impl ReportAsyncActivityCancellationInput
Sourcepub fn details_ref<T: Any>(&self) -> Option<&T>
pub fn details_ref<T: Any>(&self) -> Option<&T>
Attempt to access the cancellation details as a concrete type.
Sourcepub fn details_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn details_mut<T: Any>(&mut self) -> Option<&mut T>
Attempt to mutably access the cancellation details as a concrete type.
Sourcepub fn replace_details<T>(&mut self, details: Option<T>)where
T: TemporalSerializable + Send + 'static,
pub fn replace_details<T>(&mut self, details: Option<T>)where
T: TemporalSerializable + Send + 'static,
Replace or clear the cancellation details.