#[non_exhaustive]pub struct SignalWithStartWorkflowInput {
pub workflow_type: String,
pub signal_name: String,
pub options: WorkflowStartOptions,
pub rpc_options: RpcOptions,
/* private fields */
}Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workflow_type: StringThe workflow type sent to the server.
signal_name: StringThe signal name sent to the workflow.
options: WorkflowStartOptionsOptions for the workflow start.
rpc_options: RpcOptionsControls for the signal-with-start RPC.
Implementations
Sourceimpl SignalWithStartWorkflowInput
impl SignalWithStartWorkflowInput
Sourcepub fn workflow_args_ref<T: Any>(&self) -> Option<&T>
pub fn workflow_args_ref<T: Any>(&self) -> Option<&T>
Attempt to access the workflow arguments as a concrete type.
Sourcepub fn signal_args_ref<T: Any>(&self) -> Option<&T>
pub fn signal_args_ref<T: Any>(&self) -> Option<&T>
Attempt to access the signal arguments as a concrete type.
Sourcepub fn workflow_args_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn workflow_args_mut<T: Any>(&mut self) -> Option<&mut T>
Attempt to mutably access the workflow arguments as a concrete type.
Sourcepub fn signal_args_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn signal_args_mut<T: Any>(&mut self) -> Option<&mut T>
Attempt to mutably access the signal arguments as a concrete type.
Sourcepub fn replace_workflow_args<T>(&mut self, args: T)where
T: TemporalSerializable + Send + 'static,
pub fn replace_workflow_args<T>(&mut self, args: T)where
T: TemporalSerializable + Send + 'static,
Replace the workflow arguments before serialization.
Sourcepub fn replace_signal_args<T>(&mut self, args: T)where
T: TemporalSerializable + Send + 'static,
pub fn replace_signal_args<T>(&mut self, args: T)where
T: TemporalSerializable + Send + 'static,
Replace the signal arguments before serialization.