#[non_exhaustive]pub struct UpdateWithStartWorkflowInput {
pub workflow_type: String,
pub update_name: String,
pub options: WorkflowUpdateWithStartOptions,
pub rpc_options: RpcOptions,
/* private fields */
}Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workflow_type: StringThe workflow type sent to the server.
update_name: StringUpdate name sent to the workflow.
options: WorkflowUpdateWithStartOptionsOptions for the atomic start-and-update operation.
rpc_options: RpcOptionsControls for the multi-operation RPC.
Implementations
Sourceimpl UpdateWithStartWorkflowInput
impl UpdateWithStartWorkflowInput
Sourcepub fn workflow_args_ref<T: Any>(&self) -> Option<&T>
pub fn workflow_args_ref<T: Any>(&self) -> Option<&T>
Attempt to access the workflow start arguments as a concrete type.
Sourcepub fn workflow_args_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn workflow_args_mut<T: Any>(&mut self) -> Option<&mut T>
Attempt to mutably access the workflow start arguments as a concrete type.
Sourcepub fn replace_workflow_args<T>(&mut self, args: T)where
T: TemporalSerializable + Send + 'static,
pub fn replace_workflow_args<T>(&mut self, args: T)where
T: TemporalSerializable + Send + 'static,
Replace the workflow start arguments with another serializable value.
Sourcepub fn update_args_ref<T: Any>(&self) -> Option<&T>
pub fn update_args_ref<T: Any>(&self) -> Option<&T>
Attempt to access the update arguments as a concrete type.
Sourcepub fn update_args_mut<T: Any>(&mut self) -> Option<&mut T>
pub fn update_args_mut<T: Any>(&mut self) -> Option<&mut T>
Attempt to mutably access the update arguments as a concrete type.
Sourcepub fn replace_update_args<T>(&mut self, args: T)where
T: TemporalSerializable + Send + 'static,
pub fn replace_update_args<T>(&mut self, args: T)where
T: TemporalSerializable + Send + 'static,
Replace the update arguments with another serializable value.