pub struct ErasedClientPlugin { /* private fields */ }Expand description
A type-erased client plugin and worker-plugin propagation data.
The worker data is intentionally opaque to avoid taking a dependency on temporalio-sdk.
Experimental: This API may change or be removed.
Implementations
Sourceimpl ErasedClientPlugin
impl ErasedClientPlugin
Sourcepub fn new<P: ClientPlugin>(plugin: P) -> Self
pub fn new<P: ClientPlugin>(plugin: P) -> Self
Type-erase a client plugin for registration on ClientOptions.
Sourcepub fn with_worker_plugin<T: WorkerPluginData>(self, plugin: T) -> Self
pub fn with_worker_plugin<T: WorkerPluginData>(self, plugin: T) -> Self
Attach opaque worker-plugin propagation data.
This is intended for SDK integrations that define their own worker plugin trait. Values with types unknown to an SDK are ignored.
Sourcepub fn worker_plugins(&self) -> impl Iterator<Item = &dyn WorkerPluginData>
pub fn worker_plugins(&self) -> impl Iterator<Item = &dyn WorkerPluginData>
Iterate over opaque worker-plugin propagation data.
This is intended for SDK integrations that recognize their own private registration type.