Module request_extensions

Module request_extensions 

Request extensions for tonic gRPC requests.

These types can be inserted into tonic request extensions to modify behavior of retires or other request handling logic.

Structs

IsWorkerTaskLongPoll
A request extension that, when set, should make the retry behavior consider this call to be a CallType::TaskLongPoll
NoRetryOnMatching
A request extension that, when set, and a call is being processed by a retrying client, allows the caller to request certain matching errors to short-circuit-return immediately and not follow normal retry logic.
RetryConfigForCall
A request extension that forces overriding the current retry policy of the crate::Connection.

Traits

RequestExt
Extension trait for tonic requests to set default timeouts