pub struct NoRetryOnMatching {
pub predicate: fn(&Status) -> bool,
}Expand description
A request extension that, when set, and a call is being processed by a retrying client, allows the caller to request certain matching errors to short-circuit-return immediately and not follow normal retry logic.
Fields
predicate: fn(&Status) -> boolReturn true if the passed-in gRPC error should be immediately returned to the caller