ScheduleOverlapPolicy

Enum ScheduleOverlapPolicy 

pub enum ScheduleOverlapPolicy {
    Unspecified,
    Skip,
    BufferOne,
    BufferAll,
    CancelOther,
    TerminateOther,
    AllowAll,
}
Controls what happens when a scheduled workflow would overlap with a running one.

Variants



Unspecified

Use the server default (currently Skip).



Skip

Don’t start a new workflow if one is already running.



BufferOne

Buffer one workflow start, to run after the current one completes.



BufferAll

Buffer all workflow starts, to run sequentially.



CancelOther

Cancel the running workflow and start a new one.



TerminateOther

Terminate the running workflow and start a new one.



AllowAll

Start any number of concurrent workflows.