#[non_exhaustive]pub struct CreateScheduleOptions {
pub action: ScheduleAction,
pub spec: ScheduleSpec,
pub trigger_immediately: bool,
pub overlap_policy: ScheduleOverlapPolicy,
pub paused: bool,
pub note: String,
}Expand description
Options for creating a schedule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: ScheduleActionThe action the schedule should perform on each trigger.
spec: ScheduleSpecDefines when the schedule should trigger.
trigger_immediately: boolWhether to trigger the schedule immediately upon creation.
overlap_policy: ScheduleOverlapPolicyOverlap policy for the schedule. Also used for the initial trigger when
trigger_immediately is true.
paused: boolWhether the schedule starts in a paused state.
note: StringA note to attach to the schedule state (e.g., reason for pausing).
Implementations
Sourceimpl CreateScheduleOptions
impl CreateScheduleOptions
Sourcepub fn builder() -> CreateScheduleOptionsBuilder
pub fn builder() -> CreateScheduleOptionsBuilder
Create an instance of CreateScheduleOptions using the builder syntax