CreateScheduleOptionsBuilder

Struct CreateScheduleOptionsBuilder 

pub struct CreateScheduleOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CreateScheduleOptionsBuilder<S>

pub fn build(self) -> CreateScheduleOptions
where S: IsComplete,

Finish building and return the requested object

pub fn action( self, value: ScheduleAction, ) -> CreateScheduleOptionsBuilder<SetAction<S>>
where S::Action: IsUnset,

Required.

The action the schedule should perform on each trigger.

pub fn spec( self, value: ScheduleSpec, ) -> CreateScheduleOptionsBuilder<SetSpec<S>>
where S::Spec: IsUnset,

Required.

Defines when the schedule should trigger.

pub fn trigger_immediately( self, value: bool, ) -> CreateScheduleOptionsBuilder<SetTriggerImmediately<S>>
where S::TriggerImmediately: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to trigger the schedule immediately upon creation.

pub fn maybe_trigger_immediately( self, value: Option<bool>, ) -> CreateScheduleOptionsBuilder<SetTriggerImmediately<S>>
where S::TriggerImmediately: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to trigger the schedule immediately upon creation.

pub fn overlap_policy( self, value: ScheduleOverlapPolicy, ) -> CreateScheduleOptionsBuilder<SetOverlapPolicy<S>>
where S::OverlapPolicy: IsUnset,

Optional (Some / Option setters). Default: <ScheduleOverlapPolicy as Default>::default().

Overlap policy for the schedule. Also used for the initial trigger when trigger_immediately is true.

pub fn maybe_overlap_policy( self, value: Option<ScheduleOverlapPolicy>, ) -> CreateScheduleOptionsBuilder<SetOverlapPolicy<S>>
where S::OverlapPolicy: IsUnset,

Optional (Some / Option setters). Default: <ScheduleOverlapPolicy as Default>::default().

Overlap policy for the schedule. Also used for the initial trigger when trigger_immediately is true.

pub fn paused(self, value: bool) -> CreateScheduleOptionsBuilder<SetPaused<S>>
where S::Paused: IsUnset,

Optional (Some / Option setters). Default: false.

Whether the schedule starts in a paused state.

pub fn maybe_paused( self, value: Option<bool>, ) -> CreateScheduleOptionsBuilder<SetPaused<S>>
where S::Paused: IsUnset,

Optional (Some / Option setters). Default: false.

Whether the schedule starts in a paused state.

pub fn note( self, value: impl Into<String>, ) -> CreateScheduleOptionsBuilder<SetNote<S>>
where S::Note: IsUnset,

Optional (Some / Option setters). Default: "".

A note to attach to the schedule state (e.g., reason for pausing).

pub fn maybe_note( self, value: Option<impl Into<String>>, ) -> CreateScheduleOptionsBuilder<SetNote<S>>
where S::Note: IsUnset,

Optional (Some / Option setters). Default: "".

A note to attach to the schedule state (e.g., reason for pausing).