ActivityDescribeOptions

Struct ActivityDescribeOptions 

#[non_exhaustive]
pub struct ActivityDescribeOptions { pub include_input: bool, pub include_outcome: bool, pub include_heartbeat_details: bool, pub include_last_failure: bool, }
Controls which optional fields will be requested in ActivityHandle::describe operation. The fields will be present in returned ActivityExecutionDescription, subject to data availability and server support.

Note that these fields contain payloads that can be arbitrarily large. It’s recommended not to include them unless they’re needed.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
include_input: bool

If set and the activity received input, the input will be included.

include_outcome: bool

If set and the activity is closed, the activity outcome will be included.

include_heartbeat_details: bool

If set and the activity sent heartbeat details, the heartbeat details will be included.

include_last_failure: bool

If set and the activity has a failed attempt, the last failure will be included.

Implementations

Source

impl ActivityDescribeOptions

pub fn builder() -> ActivityDescribeOptionsBuilder

Create an instance of ActivityDescribeOptions using the builder syntax