ActivityExecutionDescription

Struct ActivityExecutionDescription 

pub struct ActivityExecutionDescription<ActivityT = UntypedActivity>
where ActivityT: ActivityDefinition,
{ /* private fields */ }
Contains the current state of the activity execution. Obtained from ActivityHandle::describe. Methods that deserialize payloads (e.g. heartbeat_details) use DataConverter of the client associated with the activity handle.

Implementations

Source

impl<ActivityT> ActivityExecutionDescription<ActivityT>
where ActivityT: ActivityDefinition,

pub fn untyped(self) -> ActivityExecutionDescription

Convert to an untyped description object.

pub fn raw_info(&self) -> &RawInfo

Raw Protobuf object from server response.

pub fn has_input(&self) -> bool

True if activity input is present. See ActivityDescribeOptions::include_input. Use input or raw_input to retrieve it.

pub fn raw_input(&self) -> Option<&Payloads>

Raw payload of activity input, if it was requested.

pub async fn input( &self, ) -> Result<Option<ActivityT::Input>, PayloadConversionError>

Deserialize activity input. Returns Ok(None) if not present. See ActivityDescribeOptions::include_input.

pub fn has_outcome(&self) -> bool

True if activity outcome is present. See ActivityDescribeOptions::include_outcome. Use outcome or raw_outcome to retrieve it.

pub fn raw_outcome(&self) -> Option<&ActivityExecutionOutcomeValue>

Raw payload of activity output, if it was requested and available.

pub async fn outcome( &self, ) -> Result<Option<Result<ActivityT::Output, IncomingError>>, PayloadConversionError>

Deserialize activity outcome. Returns Ok(None) if not present. See ActivityDescribeOptions::include_outcome.

pub fn run_state(&self) -> PendingActivityState

More detailed breakdown of ActivityExecutionStatus::Running.

pub fn schedule_to_close_timeout(&self) -> Option<Duration>

Indicates how long the caller is willing to wait for an activity completion. Limits how long retries will be attempted.

pub fn schedule_to_start_timeout(&self) -> Option<Duration>

Limits time an activity task can stay in a task queue before a worker picks it up. This timeout is always non-retryable.

pub fn start_to_close_timeout(&self) -> Option<Duration>

Maximum time a single activity attempt is allowed to execute after being picked up by a worker. This timeout is always retryable.

pub fn heartbeat_timeout(&self) -> Option<Duration>

Maximum permitted time between successful worker heartbeats.

pub fn retry_policy(&self) -> Option<RetryPolicy>

The retry policy for the activity.

pub fn has_heartbeat_details(&self) -> bool

True if heartbeat details are present. See ActivityDescribeOptions::include_heartbeat_details. Use heartbeat_details or raw_info().heartbeat_details to retrieve them.

pub async fn heartbeat_details<T: TemporalDeserializable + 'static>( &self, ) -> Result<Option<T>, PayloadConversionError>

Deserialize heartbeat details. Returns Ok(None) if not present. See ActivityDescribeOptions::include_heartbeat_details.

pub fn last_heartbeat_time(&self) -> Option<SystemTime>

Time the last heartbeat was recorded.

pub fn last_started_time(&self) -> Option<SystemTime>

Time the last attempt was started.

pub fn attempt(&self) -> u32

The attempt this activity is currently on. Incremented each time a new attempt is scheduled.

pub fn execution_duration(&self) -> Option<Duration>

How long this activity has been running for, including all attempts and backoff between attempts.

pub fn expiration_time(&self) -> Option<SystemTime>

Scheduled time + schedule to close timeout.

pub fn has_last_failure(&self) -> bool

True if last failure is present. See ActivityDescribeOptions::include_last_failure. Use last_failure() or raw_info().last_failure to retrieve it.

pub fn last_failure( &self, ) -> Result<Option<IncomingError>, PayloadConversionError>

Deserialize last failure. Returns Ok(None) if not present. See ActivityDescribeOptions::include_last_failure.

pub fn last_worker_identity(&self) -> Option<&str>

Identity of the last worker that attempted this activity.

pub fn current_retry_interval(&self) -> Option<Duration>

Time from the last attempt failure to the next activity retry.

pub fn last_attempt_complete_time(&self) -> Option<SystemTime>

The time when the last activity attempt completed.

pub fn next_attempt_schedule_time(&self) -> Option<SystemTime>

The time when the next activity attempt will be scheduled.

pub fn last_deployment_version(&self) -> Option<WorkerDeploymentVersion>

The Worker Deployment Version this activity was dispatched to most recently.

pub fn priority(&self) -> Priority

Priority metadata.

pub fn search_attributes(&self) -> Option<SearchAttributes>

Search attributes of the activity.

pub async fn static_summary( &self, ) -> Result<Option<String>, PayloadConversionError>

Deserialize static summary that was set when activity was scheduled. Returns Ok(None) if not present.

pub async fn static_details( &self, ) -> Result<Option<String>, PayloadConversionError>

Deserialize static details that were set when activity was scheduled. Returns Ok(None) if not present.

pub fn canceled_reason(&self) -> Option<&str>

Reason for activity cancellation if activity was canceled and reason was provided.

pub fn start_delay(&self) -> Option<Duration>

Time to wait before dispatching the first activity task. This delay is not applied to retry attempts.