ActivityHandle

Struct ActivityHandle 

pub struct ActivityHandle<ClientT, ActivityT>
where ActivityT: ActivityDefinition,
{ /* private fields */ }
Handle associated with a standalone activity execution that can be used to wait for the result or to manage execution of the activity. Obtained from Client::start_activity or Client::get_activity_handle.

If run_id is set, the handle always targets that specific execution. If run_id is None, each method call targets the latest run of the specified activity_id at the time the method is called - this means consecutive method calls may target different executions if an activity was started again with the same ID.

Implementations

Source

impl<ClientT, ActivityT> ActivityHandle<ClientT, ActivityT>
where ActivityT: ActivityDefinition,

pub fn activity_id(&self) -> &str

Activity ID this handle is associated with.

pub fn run_id(&self) -> Option<&str>

Run ID of the activity execution this handle is associated with. If None, each method call targets the latest run of the specified activity_id at the time the method is called - this means consecutive method calls may target different executions if an activity was started again with the same ID.

Source

impl<ClientT, ActivityT> ActivityHandle<ClientT, ActivityT>

pub async fn result(&self) -> Result<ActivityT::Output, ActivityResultError>

Wait for the activity to complete and fetch its result. If the activity was not successful (e.g. failed, canceled, timed out), this method returns ActivityResultError::ActivityFailed.

pub async fn describe( &self, options: ActivityDescribeOptions, ) -> Result<ActivityExecutionDescription<ActivityT>, ActivityInteractionError>

Describes the current state of the activity execution.

pub async fn cancel( &self, options: ActivityCancelOptions, ) -> Result<(), ActivityInteractionError>

Requests cancellation of the activity. Does not wait for the cancellation to complete.

pub async fn terminate( &self, options: ActivityTerminateOptions, ) -> Result<(), ActivityInteractionError>

Terminates activity execution.