ActivityStartOptions

Struct ActivityStartOptions 

#[non_exhaustive]
pub struct ActivityStartOptions {
Show 14 fields pub task_queue: String, pub id: String, pub close_timeouts: ActivityCloseTimeouts, pub schedule_to_start_timeout: Option<Duration>, pub heartbeat_timeout: Option<Duration>, pub retry_policy: Option<RetryPolicy>, pub priority: Priority, pub id_reuse_policy: ActivityIdReusePolicy, pub id_conflict_policy: ActivityIdConflictPolicy, pub search_attributes: Option<SearchAttributes>, pub header: Option<Header>, pub summary: Option<String>, pub static_details: Option<String>, pub start_delay: Option<Duration>,
}
Options for starting a standalone activity.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
task_queue: String

Task queue to run this activity on.

id: String

Activity ID of the started activity. It’s recommended to use a meaningful business ID.

close_timeouts: ActivityCloseTimeouts

Timeouts for activity completion.

See ActivityCloseTimeouts for the meaning of each timeout variant.

schedule_to_start_timeout: Option<Duration>

If set, specifies maximum time the activity can wait in the task queue before being picked up by a worker. This timeout is non-retryable.

heartbeat_timeout: Option<Duration>

If set, specifies maximum time between successful heartbeats.

retry_policy: Option<RetryPolicy>

Controls how Activity is retried. If not set, the server will assign default retry policy.

priority: Priority

Priority to use when starting this activity.

id_reuse_policy: ActivityIdReusePolicy

Specifies behavior if there’s a closed activity with the same ID.

id_conflict_policy: ActivityIdConflictPolicy

Specifies behavior if there’s a running activity with the same ID. Note that there can only be one running activity for each Activity ID.

search_attributes: Option<SearchAttributes>

Search attributes for the activity.

header: Option<Header>

Headers to include with the start request.

summary: Option<String>

Single-line static summary for the activity, shown in the Temporal UI.

static_details: Option<String>

Multi-line static details for the activity, shown in the Temporal UI.

start_delay: Option<Duration>

Time to wait before dispatching the first activity task. This delay is not applied to retry attempts.

Implementations

Source

impl ActivityStartOptions

pub fn new( task_queue: impl Into<String>, id: impl Into<String>, close_timeouts: ActivityCloseTimeouts, ) -> ActivityStartOptionsBuilder

Create an instance of ActivityStartOptions using the builder syntax

Source

impl ActivityStartOptions

pub fn with_start_to_close_timeout( task_queue: impl Into<String>, activity_id: impl Into<String>, start_to_close_timeout: Duration, ) -> ActivityStartOptionsBuilder

Returns a builder with close_timeouts set to ActivityCloseTimeouts::StartToClose.

pub fn with_schedule_to_close_timeout( task_queue: impl Into<String>, activity_id: impl Into<String>, schedule_to_close_timeout: Duration, ) -> ActivityStartOptionsBuilder

Returns a builder with close_timeouts set to ActivityCloseTimeouts::ScheduleToClose.