ActivityStartOptionsBuilder

Struct ActivityStartOptionsBuilder 

pub struct ActivityStartOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ActivityStartOptionsBuilder<S>

pub fn build(self) -> ActivityStartOptions
where S: IsComplete,

Finish building and return the requested object

pub fn schedule_to_start_timeout( self, value: Duration, ) -> ActivityStartOptionsBuilder<SetScheduleToStartTimeout<S>>
where S::ScheduleToStartTimeout: IsUnset,

Optional (Some / Option setters). If set, specifies maximum time the activity can wait in the task queue before being picked up by a worker. This timeout is non-retryable.

pub fn maybe_schedule_to_start_timeout( self, value: Option<Duration>, ) -> ActivityStartOptionsBuilder<SetScheduleToStartTimeout<S>>
where S::ScheduleToStartTimeout: IsUnset,

Optional (Some / Option setters). If set, specifies maximum time the activity can wait in the task queue before being picked up by a worker. This timeout is non-retryable.

pub fn heartbeat_timeout( self, value: Duration, ) -> ActivityStartOptionsBuilder<SetHeartbeatTimeout<S>>
where S::HeartbeatTimeout: IsUnset,

Optional (Some / Option setters). If set, specifies maximum time between successful heartbeats.

pub fn maybe_heartbeat_timeout( self, value: Option<Duration>, ) -> ActivityStartOptionsBuilder<SetHeartbeatTimeout<S>>
where S::HeartbeatTimeout: IsUnset,

Optional (Some / Option setters). If set, specifies maximum time between successful heartbeats.

pub fn retry_policy( self, value: impl Into<RetryPolicy>, ) -> ActivityStartOptionsBuilder<SetRetryPolicy<S>>
where S::RetryPolicy: IsUnset,

Optional (Some / Option setters). Controls how Activity is retried. If not set, the server will assign default retry policy.

pub fn maybe_retry_policy( self, value: Option<impl Into<RetryPolicy>>, ) -> ActivityStartOptionsBuilder<SetRetryPolicy<S>>
where S::RetryPolicy: IsUnset,

Optional (Some / Option setters). Controls how Activity is retried. If not set, the server will assign default retry policy.

pub fn priority( self, value: Priority, ) -> ActivityStartOptionsBuilder<SetPriority<S>>
where S::Priority: IsUnset,

Optional (Some / Option setters). Default: <Priority as Default>::default().

Priority to use when starting this activity.

pub fn maybe_priority( self, value: Option<Priority>, ) -> ActivityStartOptionsBuilder<SetPriority<S>>
where S::Priority: IsUnset,

Optional (Some / Option setters). Default: <Priority as Default>::default().

Priority to use when starting this activity.

pub fn id_reuse_policy( self, value: ActivityIdReusePolicy, ) -> ActivityStartOptionsBuilder<SetIdReusePolicy<S>>
where S::IdReusePolicy: IsUnset,

Optional (Some / Option setters). Default: <ActivityIdReusePolicy as Default>::default().

Specifies behavior if there’s a closed activity with the same ID.

pub fn maybe_id_reuse_policy( self, value: Option<ActivityIdReusePolicy>, ) -> ActivityStartOptionsBuilder<SetIdReusePolicy<S>>
where S::IdReusePolicy: IsUnset,

Optional (Some / Option setters). Default: <ActivityIdReusePolicy as Default>::default().

Specifies behavior if there’s a closed activity with the same ID.

pub fn id_conflict_policy( self, value: ActivityIdConflictPolicy, ) -> ActivityStartOptionsBuilder<SetIdConflictPolicy<S>>
where S::IdConflictPolicy: IsUnset,

Optional (Some / Option setters). Default: <ActivityIdConflictPolicy as Default>::default().

Specifies behavior if there’s a running activity with the same ID. Note that there can only be one running activity for each Activity ID.

pub fn maybe_id_conflict_policy( self, value: Option<ActivityIdConflictPolicy>, ) -> ActivityStartOptionsBuilder<SetIdConflictPolicy<S>>
where S::IdConflictPolicy: IsUnset,

Optional (Some / Option setters). Default: <ActivityIdConflictPolicy as Default>::default().

Specifies behavior if there’s a running activity with the same ID. Note that there can only be one running activity for each Activity ID.

pub fn search_attributes( self, value: SearchAttributes, ) -> ActivityStartOptionsBuilder<SetSearchAttributes<S>>
where S::SearchAttributes: IsUnset,

Optional (Some / Option setters). Search attributes for the activity.

pub fn maybe_search_attributes( self, value: Option<SearchAttributes>, ) -> ActivityStartOptionsBuilder<SetSearchAttributes<S>>
where S::SearchAttributes: IsUnset,

Optional (Some / Option setters). Search attributes for the activity.

pub fn header(self, value: Header) -> ActivityStartOptionsBuilder<SetHeader<S>>
where S::Header: IsUnset,

Optional (Some / Option setters). Headers to include with the start request.

pub fn maybe_header( self, value: Option<Header>, ) -> ActivityStartOptionsBuilder<SetHeader<S>>
where S::Header: IsUnset,

Optional (Some / Option setters). Headers to include with the start request.

pub fn summary( self, value: impl Into<String>, ) -> ActivityStartOptionsBuilder<SetSummary<S>>
where S::Summary: IsUnset,

Optional (Some / Option setters). Single-line static summary for the activity, shown in the Temporal UI.

pub fn maybe_summary( self, value: Option<impl Into<String>>, ) -> ActivityStartOptionsBuilder<SetSummary<S>>
where S::Summary: IsUnset,

Optional (Some / Option setters). Single-line static summary for the activity, shown in the Temporal UI.

pub fn static_details( self, value: impl Into<String>, ) -> ActivityStartOptionsBuilder<SetStaticDetails<S>>
where S::StaticDetails: IsUnset,

Optional (Some / Option setters). Multi-line static details for the activity, shown in the Temporal UI.

pub fn maybe_static_details( self, value: Option<impl Into<String>>, ) -> ActivityStartOptionsBuilder<SetStaticDetails<S>>
where S::StaticDetails: IsUnset,

Optional (Some / Option setters). Multi-line static details for the activity, shown in the Temporal UI.

pub fn start_delay( self, value: Duration, ) -> ActivityStartOptionsBuilder<SetStartDelay<S>>
where S::StartDelay: IsUnset,

Optional (Some / Option setters). Time to wait before dispatching the first activity task. This delay is not applied to retry attempts.

pub fn maybe_start_delay( self, value: Option<Duration>, ) -> ActivityStartOptionsBuilder<SetStartDelay<S>>
where S::StartDelay: IsUnset,

Optional (Some / Option setters). Time to wait before dispatching the first activity task. This delay is not applied to retry attempts.