pub struct Client { /* private fields */ }Expand description
Contains an instance of a namespace-bound client for interacting with the Temporal server. Cheap to clone.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn new(
connection: Connection,
options: ClientOptions,
) -> Result<Self, ClientNewError>
pub fn new( connection: Connection, options: ClientOptions, ) -> Result<Self, ClientNewError>
Create a new client from a connection and options.
Currently infallible, but returns a Result for future extensibility
(e.g., interceptor or plugin validation).
Sourcepub fn options(&self) -> &ClientOptions
pub fn options(&self) -> &ClientOptions
Return the options this client was initialized with
Sourcepub fn options_mut(&mut self) -> &mut ClientOptions
pub fn options_mut(&mut self) -> &mut ClientOptions
Return this client’s options mutably.
Note: If this client has been cloned, this will copy-on-write to avoid affecting other clones.
Sourcepub fn connection(&self) -> &Connection
pub fn connection(&self) -> &Connection
Returns a reference to the underlying connection
Sourcepub fn connection_mut(&mut self) -> &mut Connection
pub fn connection_mut(&mut self) -> &mut Connection
Returns a mutable reference to the underlying connection
Sourceimpl Client
impl Client
Sourcepub async fn start_workflow<W>(
&self,
workflow: W,
input: W::Input,
options: WorkflowStartOptions,
) -> Result<WorkflowHandle<Self, W>, WorkflowStartError>
pub async fn start_workflow<W>( &self, workflow: W, input: W::Input, options: WorkflowStartOptions, ) -> Result<WorkflowHandle<Self, W>, WorkflowStartError>
Start a workflow execution.
Returns a WorkflowHandle that can be used to interact with the workflow
(e.g., get its result, send signals, query, etc.).
Sourcepub fn get_workflow_handle<W: WorkflowDefinition>(
&self,
workflow_id: impl Into<String>,
) -> WorkflowHandle<Self, W>
pub fn get_workflow_handle<W: WorkflowDefinition>( &self, workflow_id: impl Into<String>, ) -> WorkflowHandle<Self, W>
Get a handle to an existing workflow.
For untyped access, use get_workflow_handle::<UntypedWorkflow>(...).
Sourcepub fn list_workflows(
&self,
query: impl Into<String>,
opts: WorkflowListOptions,
) -> ListWorkflowsStream
pub fn list_workflows( &self, query: impl Into<String>, opts: WorkflowListOptions, ) -> ListWorkflowsStream
List workflows matching a query.
Returns a stream that lazily paginates through results.
Use limit in options to cap the number of results returned.
Sourcepub async fn count_workflows(
&self,
query: impl Into<String>,
opts: WorkflowCountOptions,
) -> Result<WorkflowExecutionCount, ClientError>
pub async fn count_workflows( &self, query: impl Into<String>, opts: WorkflowCountOptions, ) -> Result<WorkflowExecutionCount, ClientError>
Count workflows matching a query.
Sourcepub fn get_async_activity_handle(
&self,
identifier: ActivityIdentifier,
) -> AsyncActivityHandle<Self>
pub fn get_async_activity_handle( &self, identifier: ActivityIdentifier, ) -> AsyncActivityHandle<Self>
Get a handle to complete an activity asynchronously.
An activity returning ActivityError::WillCompleteAsync can be completed with this handle.