pub struct ClientTlsOptions {
pub client_cert: Vec<u8>,
pub client_private_key: Vec<u8>,
}Expand description
If using mTLS, both the client cert and private key must be specified, this contains them.
Fields
client_cert: Vec<u8>The certificate for this client, encoded as PEM
client_private_key: Vec<u8>The private key for this client, encoded as PEM