Connection

Struct Connection 

pub struct Connection { /* private fields */ }
A connection to the Temporal service.

Cloning a connection is cheap (single Arc increment). The underlying connection is shared between clones.

Implementations

Source

impl Connection

pub async fn connect( options: ConnectionOptions, ) -> Result<Self, ClientConnectError>

Connect to a Temporal service.

pub fn set_api_key(&self, api_key: Option<String>)

Set API key, overwriting any previous one.

pub fn set_headers( &self, headers: HashMap<String, String>, ) -> Result<(), InvalidHeaderError>

Set HTTP request headers overwriting previous headers.

This will not affect headers set via ConnectionOptions::binary_headers.

Errors

Will return an error if any of the provided keys or values are not valid gRPC metadata. If an error is returned, the previous headers will remain unchanged.

pub fn set_binary_headers( &self, binary_headers: HashMap<String, Vec<u8>>, ) -> Result<(), InvalidHeaderError>

Set binary HTTP request headers overwriting previous headers.

This will not affect headers set via ConnectionOptions::headers.

Errors

Will return an error if any of the provided keys are not valid gRPC binary metadata keys. If an error is returned, the previous headers will remain unchanged.

pub fn client_name(&self) -> &str

Returns the value used for the client-name header by this connection.

pub fn client_version(&self) -> &str

Returns the value used for the client-version header by this connection.

pub fn capabilities(&self) -> Option<&Capabilities>

Returns the server capabilities we (may have) learned about when establishing an initial connection

pub fn retry_options_mut(&mut self) -> &mut RetryOptions

Get a mutable reference to the retry options.

Note: If this connection has been cloned, this will copy-on-write to avoid affecting other clones.

pub fn identity(&self) -> &str

Get a reference to the connection identity.

pub fn identity_mut(&mut self) -> &mut String

Get a mutable reference to the connection identity.

Note: If this connection has been cloned, this will copy-on-write to avoid affecting other clones.

pub fn workers(&self) -> Arc<ClientWorkerSet>

Returns a reference to a registry with workers using this client instance.

pub fn worker_grouping_key(&self) -> Uuid

Returns the client-wide key.

pub fn workflow_service(&self) -> Box<dyn WorkflowService>

Get the underlying workflow service client for making raw gRPC calls.

pub fn operator_service(&self) -> Box<dyn OperatorService>

Get the underlying operator service client for making raw gRPC calls.

pub fn cloud_service(&self) -> Box<dyn CloudService>

Get the underlying cloud service client for making raw gRPC calls.

pub fn test_service(&self) -> Box<dyn TestService>

Get the underlying test service client for making raw gRPC calls.

pub fn health_service(&self) -> Box<dyn HealthService>

Get the underlying health service client for making raw gRPC calls.