ConnectionOptionsBuilder

Struct ConnectionOptionsBuilder 

pub struct ConnectionOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ConnectionOptionsBuilder<S>

pub fn build(self) -> ConnectionOptions
where S: IsComplete,

Finish building and return the requested object

pub fn identity( self, value: impl Into<String>, ) -> ConnectionOptionsBuilder<SetIdentity<S>>
where S::Identity: IsUnset,

Optional (Some / Option setters). Default: "".

A human-readable string that can identify this process. Defaults to empty string.

pub fn maybe_identity( self, value: Option<impl Into<String>>, ) -> ConnectionOptionsBuilder<SetIdentity<S>>
where S::Identity: IsUnset,

Optional (Some / Option setters). Default: "".

A human-readable string that can identify this process. Defaults to empty string.

pub fn metrics_meter( self, value: TemporalMeter, ) -> ConnectionOptionsBuilder<SetMetricsMeter<S>>

Optional (Some / Option setters).

When set, this client will record metrics using the provided meter. The meter can be obtained from temporalio_common::telemetry::TelemetryInstance::get_temporal_metric_meter.

pub fn maybe_metrics_meter( self, value: Option<TemporalMeter>, ) -> ConnectionOptionsBuilder<SetMetricsMeter<S>>

Optional (Some / Option setters).

When set, this client will record metrics using the provided meter. The meter can be obtained from temporalio_common::telemetry::TelemetryInstance::get_temporal_metric_meter.

pub fn tls_options( self, value: TlsOptions, ) -> ConnectionOptionsBuilder<SetTlsOptions<S>>
where S::TlsOptions: IsUnset,

Optional (Some / Option setters).

If specified, use TLS as configured by the TlsOptions struct. If this is set core will attempt to use TLS when connecting to the Temporal server. Lang SDK is expected to pass any certs or keys as bytes, loading them from disk itself if needed.

pub fn maybe_tls_options( self, value: Option<TlsOptions>, ) -> ConnectionOptionsBuilder<SetTlsOptions<S>>
where S::TlsOptions: IsUnset,

Optional (Some / Option setters).

If specified, use TLS as configured by the TlsOptions struct. If this is set core will attempt to use TLS when connecting to the Temporal server. Lang SDK is expected to pass any certs or keys as bytes, loading them from disk itself if needed.

pub fn override_origin( self, value: Uri, ) -> ConnectionOptionsBuilder<SetOverrideOrigin<S>>

Optional (Some / Option setters).

If set, override the origin used when connecting. May be useful in rare situations where tls verification needs to use a different name from what should be set as the :authority header. If TlsOptions::domain is set, and this is not, this will be set to https://<domain>, effectively making the :authority header consistent with the domain override.

pub fn maybe_override_origin( self, value: Option<Uri>, ) -> ConnectionOptionsBuilder<SetOverrideOrigin<S>>

Optional (Some / Option setters).

If set, override the origin used when connecting. May be useful in rare situations where tls verification needs to use a different name from what should be set as the :authority header. If TlsOptions::domain is set, and this is not, this will be set to https://<domain>, effectively making the :authority header consistent with the domain override.

pub fn api_key( self, value: impl Into<String>, ) -> ConnectionOptionsBuilder<SetApiKey<S>>
where S::ApiKey: IsUnset,

Optional (Some / Option setters).

An API key to use for auth. If set, TLS will be enabled by default, but without any mTLS specific settings.

pub fn maybe_api_key( self, value: Option<impl Into<String>>, ) -> ConnectionOptionsBuilder<SetApiKey<S>>
where S::ApiKey: IsUnset,

Optional (Some / Option setters).

An API key to use for auth. If set, TLS will be enabled by default, but without any mTLS specific settings.

pub fn retry_options( self, value: RetryOptions, ) -> ConnectionOptionsBuilder<SetRetryOptions<S>>

Optional (Some / Option setters). Default: <RetryOptions as Default>::default().

Retry configuration for the server client. Default is RetryOptions::default

pub fn maybe_retry_options( self, value: Option<RetryOptions>, ) -> ConnectionOptionsBuilder<SetRetryOptions<S>>

Optional (Some / Option setters). Default: <RetryOptions as Default>::default().

Retry configuration for the server client. Default is RetryOptions::default

pub fn keep_alive( self, value: Option<ClientKeepAliveOptions>, ) -> ConnectionOptionsBuilder<SetKeepAlive<S>>
where S::KeepAlive: IsUnset,

Optional (Some / Option setters). Default: Some(ClientKeepAliveOptions::default()).

If set, HTTP2 gRPC keep alive will be enabled. To enable with default settings, use .keep_alive(Some(ClientKeepAliveConfig::default())).

pub fn maybe_keep_alive( self, value: Option<Option<ClientKeepAliveOptions>>, ) -> ConnectionOptionsBuilder<SetKeepAlive<S>>
where S::KeepAlive: IsUnset,

Optional (Some / Option setters). Default: Some(ClientKeepAliveOptions::default()).

If set, HTTP2 gRPC keep alive will be enabled. To enable with default settings, use .keep_alive(Some(ClientKeepAliveConfig::default())).

pub fn headers( self, value: HashMap<String, String>, ) -> ConnectionOptionsBuilder<SetHeaders<S>>
where S::Headers: IsUnset,

Optional (Some / Option setters).

HTTP headers to include on every RPC call.

These must be valid gRPC metadata keys, and must not be binary metadata keys (ending in `-bin). To set binary headers, use ConnectionOptions::binary_headers. Invalid header keys or values will cause an error to be returned when connecting.

pub fn maybe_headers( self, value: Option<HashMap<String, String>>, ) -> ConnectionOptionsBuilder<SetHeaders<S>>
where S::Headers: IsUnset,

Optional (Some / Option setters).

HTTP headers to include on every RPC call.

These must be valid gRPC metadata keys, and must not be binary metadata keys (ending in `-bin). To set binary headers, use ConnectionOptions::binary_headers. Invalid header keys or values will cause an error to be returned when connecting.

pub fn binary_headers( self, value: HashMap<String, Vec<u8>>, ) -> ConnectionOptionsBuilder<SetBinaryHeaders<S>>

Optional (Some / Option setters).

HTTP headers to include on every RPC call as binary gRPC metadata (encoded as base64).

These must be valid binary gRPC metadata keys (and end with a -bin suffix). Invalid header keys will cause an error to be returned when connecting.

pub fn maybe_binary_headers( self, value: Option<HashMap<String, Vec<u8>>>, ) -> ConnectionOptionsBuilder<SetBinaryHeaders<S>>

Optional (Some / Option setters).

HTTP headers to include on every RPC call as binary gRPC metadata (encoded as base64).

These must be valid binary gRPC metadata keys (and end with a -bin suffix). Invalid header keys will cause an error to be returned when connecting.

pub fn http_connect_proxy( self, value: HttpConnectProxyOptions, ) -> ConnectionOptionsBuilder<SetHttpConnectProxy<S>>

Optional (Some / Option setters).

HTTP CONNECT proxy to use for this client.

pub fn maybe_http_connect_proxy( self, value: Option<HttpConnectProxyOptions>, ) -> ConnectionOptionsBuilder<SetHttpConnectProxy<S>>

Optional (Some / Option setters).

HTTP CONNECT proxy to use for this client.

pub fn disable_error_code_metric_tags( self, value: bool, ) -> ConnectionOptionsBuilder<SetDisableErrorCodeMetricTags<S>>

Optional (Some / Option setters). Default: false.

If set true, error code labels will not be included on request failure metrics.

pub fn maybe_disable_error_code_metric_tags( self, value: Option<bool>, ) -> ConnectionOptionsBuilder<SetDisableErrorCodeMetricTags<S>>

Optional (Some / Option setters). Default: false.

If set true, error code labels will not be included on request failure metrics.

pub fn service_override( self, value: CallbackBasedGrpcService, ) -> ConnectionOptionsBuilder<SetServiceOverride<S>>

Optional (Some / Option setters).

If set, all gRPC calls will be routed through the provided service.

pub fn maybe_service_override( self, value: Option<CallbackBasedGrpcService>, ) -> ConnectionOptionsBuilder<SetServiceOverride<S>>

Optional (Some / Option setters).

If set, all gRPC calls will be routed through the provided service.

pub fn skip_get_system_info( self, value: bool, ) -> ConnectionOptionsBuilder<SetSkipGetSystemInfo<S>>

Optional (Some / Option setters). Default: false.

If set true, get_system_info will not be called upon connection.

pub fn maybe_skip_get_system_info( self, value: Option<bool>, ) -> ConnectionOptionsBuilder<SetSkipGetSystemInfo<S>>

Optional (Some / Option setters). Default: false.

If set true, get_system_info will not be called upon connection.

pub fn client_name( self, value: impl Into<String>, ) -> ConnectionOptionsBuilder<SetClientName<S>>
where S::ClientName: IsUnset,

Optional (Some / Option setters). Default: "temporal-rust".to_owned().

The name of the SDK being implemented on top of core. Is set as client-name header in all RPC calls

pub fn maybe_client_name( self, value: Option<impl Into<String>>, ) -> ConnectionOptionsBuilder<SetClientName<S>>
where S::ClientName: IsUnset,

Optional (Some / Option setters). Default: "temporal-rust".to_owned().

The name of the SDK being implemented on top of core. Is set as client-name header in all RPC calls

pub fn client_version( self, value: impl Into<String>, ) -> ConnectionOptionsBuilder<SetClientVersion<S>>

Optional (Some / Option setters). Default: VERSION.to_owned().

The version of the SDK being implemented on top of core. Is set as client-version header in all RPC calls. The server decides if the client is supported based on this.

pub fn maybe_client_version( self, value: Option<impl Into<String>>, ) -> ConnectionOptionsBuilder<SetClientVersion<S>>

Optional (Some / Option setters). Default: VERSION.to_owned().

The version of the SDK being implemented on top of core. Is set as client-version header in all RPC calls. The server decides if the client is supported based on this.