pub struct RetryOptions {
pub initial_interval: Duration,
pub randomization_factor: f64,
pub multiplier: f64,
pub max_interval: Duration,
pub max_elapsed_time: Option<Duration>,
pub max_retries: usize,
}Expand description
Configuration for retrying requests to the server
Fields
initial_interval: Durationinitial wait time before the first retry.
randomization_factor: f64randomization jitter that is used as a multiplier for the current retry interval and is added or subtracted from the interval length.
multiplier: f64rate at which retry time should be increased, until it reaches max_interval.
max_interval: Durationmaximum amount of time to wait between retries.
max_elapsed_time: Option<Duration>maximum total amount of time requests should be retried for, if None is set then no limit will be used.
max_retries: usizemaximum number of retry attempts.
Implementations
Sourceimpl RetryOptions
impl RetryOptions
Sourcepub const fn no_retries() -> Self
pub const fn no_retries() -> Self
A retry policy that never retires