#[non_exhaustive]pub struct RetryPolicy { /* private fields */ }Expand description
Options for retrying workflows and activities.
Durations longer than 10,000 years are clamped to the maximum valid protobuf duration.
Implementations
Sourceimpl RetryPolicy
impl RetryPolicy
Sourcepub fn initial_interval(&self) -> Duration
pub fn initial_interval(&self) -> Duration
Backoff interval for the first retry.
Sourcepub fn set_initial_interval(
&mut self,
initial_interval: Duration,
) -> &mut RetryPolicy
pub fn set_initial_interval( &mut self, initial_interval: Duration, ) -> &mut RetryPolicy
Set the backoff interval for the first retry.
Sourcepub fn backoff_coefficient(&self) -> f64
pub fn backoff_coefficient(&self) -> f64
Coefficient used to calculate the next retry interval.
Sourcepub fn set_backoff_coefficient(
&mut self,
backoff_coefficient: f64,
) -> &mut RetryPolicy
pub fn set_backoff_coefficient( &mut self, backoff_coefficient: f64, ) -> &mut RetryPolicy
Set the coefficient used to calculate the next retry interval.
Sourcepub fn maximum_interval(&self) -> Option<Duration>
pub fn maximum_interval(&self) -> Option<Duration>
Maximum backoff interval between retries.
Sourcepub fn set_maximum_interval(
&mut self,
maximum_interval: Option<Duration>,
) -> &mut RetryPolicy
pub fn set_maximum_interval( &mut self, maximum_interval: Option<Duration>, ) -> &mut RetryPolicy
Set the maximum backoff interval between retries.
Sourcepub fn maximum_attempts(&self) -> u32
pub fn maximum_attempts(&self) -> u32
Maximum number of attempts. Zero means unlimited attempts.
Sourcepub fn set_maximum_attempts(
&mut self,
maximum_attempts: u32,
) -> &mut RetryPolicy
pub fn set_maximum_attempts( &mut self, maximum_attempts: u32, ) -> &mut RetryPolicy
Sourcepub fn non_retryable_error_types(&self) -> &[String]
pub fn non_retryable_error_types(&self) -> &[String]
Error type names that should not be retried.
Sourcepub fn set_non_retryable_error_types(
&mut self,
values: impl IntoIterator<Item = impl Into<String>>,
) -> &mut RetryPolicy
pub fn set_non_retryable_error_types( &mut self, values: impl IntoIterator<Item = impl Into<String>>, ) -> &mut RetryPolicy
Set the error type names that should not be retried.
Sourcepub fn raw(&self) -> &RetryPolicy
pub fn raw(&self) -> &RetryPolicy
Access the underlying retry policy protobuf.
Sourcepub fn into_raw(self) -> RetryPolicy
pub fn into_raw(self) -> RetryPolicy
Consume this wrapper and return the underlying retry policy protobuf.