pub struct RpcMetadata { /* private fields */ }Expand description
Metadata attached to a single high-level client RPC.
Per-call values take precedence over metadata configured on the connection.
Implementations
Sourceimpl RpcMetadata
impl RpcMetadata
Sourcepub fn insert(
&mut self,
key: impl Into<String>,
value: impl Into<String>,
) -> Result<Option<String>, RpcMetadataError>
pub fn insert( &mut self, key: impl Into<String>, value: impl Into<String>, ) -> Result<Option<String>, RpcMetadataError>
Insert an ASCII metadata value, returning the previous value for the key.
Sourcepub fn insert_binary(
&mut self,
key: impl Into<String>,
value: impl Into<Vec<u8>>,
) -> Result<Option<Vec<u8>>, RpcMetadataError>
pub fn insert_binary( &mut self, key: impl Into<String>, value: impl Into<Vec<u8>>, ) -> Result<Option<Vec<u8>>, RpcMetadataError>
Insert a binary metadata value, returning the previous value for the key.
Sourcepub fn remove_ascii(&mut self, key: &str) -> Option<String>
pub fn remove_ascii(&mut self, key: &str) -> Option<String>
Remove an ASCII metadata value.