TlsOptionsBuilder

Struct TlsOptionsBuilder 

pub struct TlsOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> TlsOptionsBuilder<S>

pub fn build(self) -> TlsOptions
where S: IsComplete,

Finish building and return the requested object

pub fn server_root_ca_cert( self, value: Vec<u8>, ) -> TlsOptionsBuilder<SetServerRootCaCert<S>>
where S::ServerRootCaCert: IsUnset,

Optional (Some / Option setters). Bytes representing the root CA certificate used by the server. If not set, and the server’s cert is issued by someone the operating system trusts, verification will still work (ex: Cloud offering).

pub fn maybe_server_root_ca_cert( self, value: Option<Vec<u8>>, ) -> TlsOptionsBuilder<SetServerRootCaCert<S>>
where S::ServerRootCaCert: IsUnset,

Optional (Some / Option setters). Bytes representing the root CA certificate used by the server. If not set, and the server’s cert is issued by someone the operating system trusts, verification will still work (ex: Cloud offering).

pub fn domain(self, value: String) -> TlsOptionsBuilder<SetDomain<S>>
where S::Domain: IsUnset,

Optional (Some / Option setters). Sets the domain name against which to verify the server’s TLS certificate. If not provided, the domain name will be extracted from the URL used to connect.

pub fn maybe_domain( self, value: Option<String>, ) -> TlsOptionsBuilder<SetDomain<S>>
where S::Domain: IsUnset,

Optional (Some / Option setters). Sets the domain name against which to verify the server’s TLS certificate. If not provided, the domain name will be extracted from the URL used to connect.

pub fn client_tls_options( self, value: ClientTlsOptions, ) -> TlsOptionsBuilder<SetClientTlsOptions<S>>
where S::ClientTlsOptions: IsUnset,

Optional (Some / Option setters). TLS info for the client. If specified, core will attempt to use mTLS.

Mutually exclusive with client_cert_resolver. Setting both is an error.

pub fn maybe_client_tls_options( self, value: Option<ClientTlsOptions>, ) -> TlsOptionsBuilder<SetClientTlsOptions<S>>
where S::ClientTlsOptions: IsUnset,

Optional (Some / Option setters). TLS info for the client. If specified, core will attempt to use mTLS.

Mutually exclusive with client_cert_resolver. Setting both is an error.

pub fn server_cert_verifier( self, value: Arc<dyn ServerCertVerifier>, ) -> TlsOptionsBuilder<SetServerCertVerifier<S>>
where S::ServerCertVerifier: IsUnset,

Optional (Some / Option setters). Optional custom server certificate verifier. When set, this replaces the default certificate verification and server_root_ca_cert is ignored.

This is useful for:

  • Certificate pinning
  • Custom trust-domain validation (e.g., SAN-URI extraction)
  • Federated root certificate stores
WARNING

Implementing a custom ServerCertVerifier can lead to severely insecure TLS connections (e.g., disabling all validation or allowing man-in-the-middle attacks) if not done carefully. Only use this if you know exactly what you are doing.

The verifier must implement ServerCertVerifier from the rustls crate. Note that domain is still respected for the :authority header / origin override even when a custom verifier is set.

pub fn maybe_server_cert_verifier( self, value: Option<Arc<dyn ServerCertVerifier>>, ) -> TlsOptionsBuilder<SetServerCertVerifier<S>>
where S::ServerCertVerifier: IsUnset,

Optional (Some / Option setters). Optional custom server certificate verifier. When set, this replaces the default certificate verification and server_root_ca_cert is ignored.

This is useful for:

  • Certificate pinning
  • Custom trust-domain validation (e.g., SAN-URI extraction)
  • Federated root certificate stores
WARNING

Implementing a custom ServerCertVerifier can lead to severely insecure TLS connections (e.g., disabling all validation or allowing man-in-the-middle attacks) if not done carefully. Only use this if you know exactly what you are doing.

The verifier must implement ServerCertVerifier from the rustls crate. Note that domain is still respected for the :authority header / origin override even when a custom verifier is set.