WorkflowExecution

Struct WorkflowExecution 

pub struct WorkflowExecution { /* private fields */ }
A workflow execution returned from list operations. This represents information about a workflow present in visibility.

Implementations

Source

impl WorkflowExecution

pub fn new(raw: WorkflowExecutionInfo) -> Self

Create a new WorkflowExecution from the raw proto.

pub fn id(&self) -> &str

The workflow ID.

pub fn run_id(&self) -> &str

The run ID.

pub fn workflow_type(&self) -> &str

The workflow type name.

pub fn status(&self) -> WorkflowExecutionStatus

The current status of the workflow execution.

pub fn start_time(&self) -> Option<SystemTime>

When the workflow was created.

pub fn execution_time(&self) -> Option<SystemTime>

When the workflow run started or should start.

pub fn close_time(&self) -> Option<SystemTime>

When the workflow was closed, if closed.

pub fn task_queue(&self) -> &str

The task queue the workflow runs on.

pub fn history_length(&self) -> i64

Number of events in history.

pub fn memo(&self) -> Option<&Memo>

Workflow memo.

pub fn parent_id(&self) -> Option<&str>

Parent workflow ID, if this is a child workflow.

pub fn parent_run_id(&self) -> Option<&str>

Parent run ID, if this is a child workflow.

pub fn search_attributes(&self) -> Option<&SearchAttributes>

Search attributes on the workflow.

pub fn raw(&self) -> &WorkflowExecutionInfo

Access the raw proto for additional fields not exposed via accessors.

pub fn into_raw(self) -> WorkflowExecutionInfo

Consume the wrapper and return the raw proto.