pub struct WorkflowExecutionDescription {
pub raw_description: DescribeWorkflowExecutionResponse,
/* private fields */
}Expand description
Description of a workflow execution returned by WorkflowHandle::describe.
Access to the underlying Protobuf message is provided by raw.
Fields
raw_description: DescribeWorkflowExecutionResponseThe raw proto response from the server.
Implementations
Sourceimpl WorkflowExecutionDescription
impl WorkflowExecutionDescription
Sourcepub fn workflow_type(&self) -> &str
pub fn workflow_type(&self) -> &str
The workflow type name.
Sourcepub fn status(&self) -> WorkflowExecutionStatus
pub fn status(&self) -> WorkflowExecutionStatus
The current status of the workflow execution.
Sourcepub fn start_time(&self) -> Option<SystemTime>
pub fn start_time(&self) -> Option<SystemTime>
When the workflow was created.
Sourcepub fn execution_time(&self) -> Option<SystemTime>
pub fn execution_time(&self) -> Option<SystemTime>
When the workflow run started or should start.
Sourcepub fn close_time(&self) -> Option<SystemTime>
pub fn close_time(&self) -> Option<SystemTime>
When the workflow was closed, if closed.
Sourcepub fn task_queue(&self) -> &str
pub fn task_queue(&self) -> &str
The task queue the workflow runs on.
Sourcepub fn history_length(&self) -> usize
pub fn history_length(&self) -> usize
Number of events in history.
Sourcepub fn parent_run_id(&self) -> Option<&str>
pub fn parent_run_id(&self) -> Option<&str>
Parent run ID, if this is a child workflow.
Sourcepub fn search_attributes(&self) -> Option<&SearchAttributes>
pub fn search_attributes(&self) -> Option<&SearchAttributes>
Search attributes on the workflow.
Sourcepub fn static_summary(&self) -> Option<&str>
pub fn static_summary(&self) -> Option<&str>
Static summary configured on the workflow, if present.
Sourcepub fn static_details(&self) -> Option<&str>
pub fn static_details(&self) -> Option<&str>
Static details configured on the workflow, if present.
Sourcepub fn raw(&self) -> &DescribeWorkflowExecutionResponse
pub fn raw(&self) -> &DescribeWorkflowExecutionResponse
Access the raw proto for additional fields not exposed via accessors.
Sourcepub fn into_raw(self) -> DescribeWorkflowExecutionResponse
pub fn into_raw(self) -> DescribeWorkflowExecutionResponse
Consume the wrapper and return the raw proto.