WorkflowHandle

Struct WorkflowHandle 

pub struct WorkflowHandle<ClientT, W> { /* private fields */ }
A workflow handle which can refer to a specific workflow run, or a chain of workflow runs with the same workflow id.

Implementations

Source

impl<CT, W> WorkflowHandle<CT, W>

pub fn run_id(&self) -> Option<&str>

Return the run id of the Workflow Execution pointed at by this handle, if there is one.

Source

impl<CT, W> WorkflowHandle<CT, W>

pub fn new(client: CT, info: WorkflowExecutionInfo) -> Self

Create a workflow handle from a client and identifying information.

pub fn info(&self) -> &WorkflowExecutionInfo

Get the workflow execution info

pub fn client(&self) -> &CT

Get the client attached to this handle

pub async fn get_result( &self, opts: WorkflowGetResultOptions, ) -> Result<W::Output, WorkflowGetResultError>

Await the result of the workflow execution

pub async fn signal<S>( &self, signal: S, input: S::Input, opts: WorkflowSignalOptions, ) -> Result<(), WorkflowInteractionError>
where CT: WorkflowService + NamespacedClient + Clone, S: SignalDefinition<Workflow = W>, S::Input: Send,

Send a signal to the workflow

pub async fn query<Q>( &self, query: Q, input: Q::Input, opts: WorkflowQueryOptions, ) -> Result<Q::Output, WorkflowQueryError>
where CT: WorkflowService + NamespacedClient + Clone, Q: QueryDefinition<Workflow = W>, Q::Input: Send,

Query the workflow

pub async fn execute_update<U>( &self, update: U, input: U::Input, options: WorkflowExecuteUpdateOptions, ) -> Result<U::Output, WorkflowUpdateError>
where CT: WorkflowService + NamespacedClient + Clone, U: UpdateDefinition<Workflow = W>, U::Input: Send, U::Output: 'static,

Send an update to the workflow and wait for it to complete, returning the result.

pub async fn start_update<U>( &self, update: U, input: U::Input, options: WorkflowStartUpdateOptions, ) -> Result<WorkflowUpdateHandle<CT, U::Output>, WorkflowUpdateError>
where CT: WorkflowService + NamespacedClient + Clone, U: UpdateDefinition<Workflow = W>, U::Input: Send,

Start an update and return a handle without waiting for completion. Use execute_update() if you want to wait for the result immediately.

pub async fn cancel( &self, opts: WorkflowCancelOptions, ) -> Result<(), WorkflowInteractionError>
where CT: NamespacedClient,

Request cancellation of this workflow.

pub async fn terminate( &self, opts: WorkflowTerminateOptions, ) -> Result<(), WorkflowInteractionError>
where CT: NamespacedClient,

Terminate this workflow.

pub async fn describe( &self, _opts: WorkflowDescribeOptions, ) -> Result<WorkflowExecutionDescription, WorkflowInteractionError>
where CT: NamespacedClient,

Get workflow execution description/metadata.

pub async fn fetch_history( &self, opts: WorkflowFetchHistoryOptions, ) -> Result<WorkflowHistory, WorkflowInteractionError>
where CT: NamespacedClient,

Fetch workflow execution history.