#[non_exhaustive]pub struct WorkflowStartOptions {Show 16 fields
pub task_queue: String,
pub workflow_id: String,
pub id_reuse_policy: WorkflowIdReusePolicy,
pub id_conflict_policy: WorkflowIdConflictPolicy,
pub execution_timeout: Option<Duration>,
pub run_timeout: Option<Duration>,
pub task_timeout: Option<Duration>,
pub cron_schedule: Option<String>,
pub search_attributes: Option<HashMap<String, Payload>>,
pub enable_eager_workflow_start: bool,
pub retry_policy: Option<RetryPolicy>,
pub start_signal: Option<WorkflowStartSignal>,
pub links: Vec<Link>,
pub completion_callbacks: Vec<Callback>,
pub priority: Priority,
pub header: Option<Header>,
}Expand description
Options for starting a workflow execution.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.task_queue: StringThe task queue to run the workflow on.
workflow_id: StringThe workflow ID.
id_reuse_policy: WorkflowIdReusePolicySet the policy for reusing the workflow id
id_conflict_policy: WorkflowIdConflictPolicySet the policy for how to resolve conflicts with running policies. NOTE: This is ignored for child workflows.
execution_timeout: Option<Duration>Optionally set the execution timeout for the workflow https://docs.temporal.io/workflows/#workflow-execution-timeout
run_timeout: Option<Duration>Optionally indicates the default run timeout for a workflow run
task_timeout: Option<Duration>Optionally indicates the default task timeout for a workflow run
cron_schedule: Option<String>Optionally set a cron schedule for the workflow
search_attributes: Option<HashMap<String, Payload>>Optionally associate extra search attributes with a workflow
enable_eager_workflow_start: boolOptionally enable Eager Workflow Start, a latency optimization using local workers NOTE: Experimental
retry_policy: Option<RetryPolicy>Optionally set a retry policy for the workflow
start_signal: Option<WorkflowStartSignal>If set, send a signal to the workflow atomically with start. The workflow will receive this signal before its first task.
links: Vec<Link>Links to associate with the workflow. Ex: References to a nexus operation.
completion_callbacks: Vec<Callback>Callbacks that will be invoked upon workflow completion. For, ex, completing nexus operations.
priority: PriorityPriority for the workflow. Defaults to all-inherited (empty).
header: Option<Header>Headers to include with the start request.
Implementations
Sourceimpl WorkflowStartOptions
impl WorkflowStartOptions
Sourcepub fn new(
task_queue: impl Into<String>,
workflow_id: impl Into<String>,
) -> WorkflowStartOptionsBuilder
pub fn new( task_queue: impl Into<String>, workflow_id: impl Into<String>, ) -> WorkflowStartOptionsBuilder
Create an instance of WorkflowStartOptions using the builder syntax