WorkflowStartOptionsBuilder

Struct WorkflowStartOptionsBuilder 

pub struct WorkflowStartOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> WorkflowStartOptionsBuilder<S>

pub fn build(self) -> WorkflowStartOptions
where S: IsComplete,

Finish building and return the requested object

pub fn id_reuse_policy( self, value: WorkflowIdReusePolicy, ) -> WorkflowStartOptionsBuilder<SetIdReusePolicy<S>>
where S::IdReusePolicy: IsUnset,

Optional (Some / Option setters). Default: <WorkflowIdReusePolicy as Default>::default().

Set the policy for reusing the workflow id

pub fn maybe_id_reuse_policy( self, value: Option<WorkflowIdReusePolicy>, ) -> WorkflowStartOptionsBuilder<SetIdReusePolicy<S>>
where S::IdReusePolicy: IsUnset,

Optional (Some / Option setters). Default: <WorkflowIdReusePolicy as Default>::default().

Set the policy for reusing the workflow id

pub fn id_conflict_policy( self, value: WorkflowIdConflictPolicy, ) -> WorkflowStartOptionsBuilder<SetIdConflictPolicy<S>>
where S::IdConflictPolicy: IsUnset,

Optional (Some / Option setters). Default: <WorkflowIdConflictPolicy as Default>::default().

Set the policy for how to resolve conflicts with running policies. NOTE: This is ignored for child workflows.

pub fn maybe_id_conflict_policy( self, value: Option<WorkflowIdConflictPolicy>, ) -> WorkflowStartOptionsBuilder<SetIdConflictPolicy<S>>
where S::IdConflictPolicy: IsUnset,

Optional (Some / Option setters). Default: <WorkflowIdConflictPolicy as Default>::default().

Set the policy for how to resolve conflicts with running policies. NOTE: This is ignored for child workflows.

pub fn execution_timeout( self, value: Duration, ) -> WorkflowStartOptionsBuilder<SetExecutionTimeout<S>>
where S::ExecutionTimeout: IsUnset,

Optional (Some / Option setters).

Optionally set the execution timeout for the workflow https://docs.temporal.io/workflows/#workflow-execution-timeout

pub fn maybe_execution_timeout( self, value: Option<Duration>, ) -> WorkflowStartOptionsBuilder<SetExecutionTimeout<S>>
where S::ExecutionTimeout: IsUnset,

Optional (Some / Option setters).

Optionally set the execution timeout for the workflow https://docs.temporal.io/workflows/#workflow-execution-timeout

pub fn run_timeout( self, value: Duration, ) -> WorkflowStartOptionsBuilder<SetRunTimeout<S>>
where S::RunTimeout: IsUnset,

Optional (Some / Option setters).

Optionally indicates the default run timeout for a workflow run

pub fn maybe_run_timeout( self, value: Option<Duration>, ) -> WorkflowStartOptionsBuilder<SetRunTimeout<S>>
where S::RunTimeout: IsUnset,

Optional (Some / Option setters).

Optionally indicates the default run timeout for a workflow run

pub fn task_timeout( self, value: Duration, ) -> WorkflowStartOptionsBuilder<SetTaskTimeout<S>>
where S::TaskTimeout: IsUnset,

Optional (Some / Option setters).

Optionally indicates the default task timeout for a workflow run

pub fn maybe_task_timeout( self, value: Option<Duration>, ) -> WorkflowStartOptionsBuilder<SetTaskTimeout<S>>
where S::TaskTimeout: IsUnset,

Optional (Some / Option setters).

Optionally indicates the default task timeout for a workflow run

pub fn cron_schedule( self, value: impl Into<String>, ) -> WorkflowStartOptionsBuilder<SetCronSchedule<S>>
where S::CronSchedule: IsUnset,

Optional (Some / Option setters).

Optionally set a cron schedule for the workflow

pub fn maybe_cron_schedule( self, value: Option<impl Into<String>>, ) -> WorkflowStartOptionsBuilder<SetCronSchedule<S>>
where S::CronSchedule: IsUnset,

Optional (Some / Option setters).

Optionally set a cron schedule for the workflow

pub fn search_attributes( self, value: HashMap<String, Payload>, ) -> WorkflowStartOptionsBuilder<SetSearchAttributes<S>>
where S::SearchAttributes: IsUnset,

Optional (Some / Option setters).

Optionally associate extra search attributes with a workflow

pub fn maybe_search_attributes( self, value: Option<HashMap<String, Payload>>, ) -> WorkflowStartOptionsBuilder<SetSearchAttributes<S>>
where S::SearchAttributes: IsUnset,

Optional (Some / Option setters).

Optionally associate extra search attributes with a workflow

pub fn enable_eager_workflow_start( self, value: bool, ) -> WorkflowStartOptionsBuilder<SetEnableEagerWorkflowStart<S>>
where S::EnableEagerWorkflowStart: IsUnset,

Optional (Some / Option setters). Default: false.

Optionally enable Eager Workflow Start, a latency optimization using local workers NOTE: Experimental

pub fn maybe_enable_eager_workflow_start( self, value: Option<bool>, ) -> WorkflowStartOptionsBuilder<SetEnableEagerWorkflowStart<S>>
where S::EnableEagerWorkflowStart: IsUnset,

Optional (Some / Option setters). Default: false.

Optionally enable Eager Workflow Start, a latency optimization using local workers NOTE: Experimental

pub fn retry_policy( self, value: RetryPolicy, ) -> WorkflowStartOptionsBuilder<SetRetryPolicy<S>>
where S::RetryPolicy: IsUnset,

Optional (Some / Option setters).

Optionally set a retry policy for the workflow

pub fn maybe_retry_policy( self, value: Option<RetryPolicy>, ) -> WorkflowStartOptionsBuilder<SetRetryPolicy<S>>
where S::RetryPolicy: IsUnset,

Optional (Some / Option setters).

Optionally set a retry policy for the workflow

pub fn start_signal( self, value: WorkflowStartSignal, ) -> WorkflowStartOptionsBuilder<SetStartSignal<S>>
where S::StartSignal: IsUnset,

Optional (Some / Option setters).

If set, send a signal to the workflow atomically with start. The workflow will receive this signal before its first task.

pub fn maybe_start_signal( self, value: Option<WorkflowStartSignal>, ) -> WorkflowStartOptionsBuilder<SetStartSignal<S>>
where S::StartSignal: IsUnset,

Optional (Some / Option setters).

If set, send a signal to the workflow atomically with start. The workflow will receive this signal before its first task.

Optional (Some / Option setters). Default: <Vec<common::v1::Link> as Default>::default().

Links to associate with the workflow. Ex: References to a nexus operation.

Optional (Some / Option setters). Default: <Vec<common::v1::Link> as Default>::default().

Links to associate with the workflow. Ex: References to a nexus operation.

pub fn completion_callbacks( self, value: Vec<Callback>, ) -> WorkflowStartOptionsBuilder<SetCompletionCallbacks<S>>
where S::CompletionCallbacks: IsUnset,

Optional (Some / Option setters). Default: <Vec<common::v1::Callback> as Default>::default().

Callbacks that will be invoked upon workflow completion. For, ex, completing nexus operations.

pub fn maybe_completion_callbacks( self, value: Option<Vec<Callback>>, ) -> WorkflowStartOptionsBuilder<SetCompletionCallbacks<S>>
where S::CompletionCallbacks: IsUnset,

Optional (Some / Option setters). Default: <Vec<common::v1::Callback> as Default>::default().

Callbacks that will be invoked upon workflow completion. For, ex, completing nexus operations.

pub fn priority( self, value: Priority, ) -> WorkflowStartOptionsBuilder<SetPriority<S>>
where S::Priority: IsUnset,

Optional (Some / Option setters). Default: <Priority as Default>::default().

Priority for the workflow. Defaults to all-inherited (empty).

pub fn maybe_priority( self, value: Option<Priority>, ) -> WorkflowStartOptionsBuilder<SetPriority<S>>
where S::Priority: IsUnset,

Optional (Some / Option setters). Default: <Priority as Default>::default().

Priority for the workflow. Defaults to all-inherited (empty).

pub fn header(self, value: Header) -> WorkflowStartOptionsBuilder<SetHeader<S>>
where S::Header: IsUnset,

Optional (Some / Option setters).

Headers to include with the start request.

pub fn maybe_header( self, value: Option<Header>, ) -> WorkflowStartOptionsBuilder<SetHeader<S>>
where S::Header: IsUnset,

Optional (Some / Option setters).

Headers to include with the start request.