#[non_exhaustive]pub struct WorkflowStartUpdateOptions {
pub update_id: Option<String>,
pub header: Option<Header>,
pub wait_for_stage: WorkflowUpdateWaitStage,
}Expand description
Options for starting an update without waiting for completion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_id: Option<String>Update ID for idempotency. If not provided, a UUID will be generated.
header: Option<Header>Headers to include with the update.
wait_for_stage: WorkflowUpdateWaitStageThe lifecycle stage to wait for before returning the handle.
Implementations
Sourceimpl WorkflowStartUpdateOptions
impl WorkflowStartUpdateOptions
Sourcepub fn builder() -> WorkflowStartUpdateOptionsBuilder
pub fn builder() -> WorkflowStartUpdateOptionsBuilder
Create an instance of WorkflowStartUpdateOptions using the builder syntax