pub struct WorkflowUpdateHandle<CT, T> { /* private fields */ }Expand description
Handle to a workflow update that has been started but may not be complete.
Use get_result() to wait for the update to complete and retrieve its result.
Implementations
Sourceimpl<CT, T> WorkflowUpdateHandle<CT, T>
impl<CT, T> WorkflowUpdateHandle<CT, T>
Sourcepub fn workflow_id(&self) -> &str
pub fn workflow_id(&self) -> &str
Get the workflow ID.
Sourcepub fn workflow_run_id(&self) -> Option<&str>
pub fn workflow_run_id(&self) -> Option<&str>
Get the workflow run ID, if available.
Sourceimpl<CT, T: 'static> WorkflowUpdateHandle<CT, T>
impl<CT, T: 'static> WorkflowUpdateHandle<CT, T>
Sourcepub async fn get_result(&self) -> Result<T, WorkflowUpdateError>where
T: TemporalDeserializable,
pub async fn get_result(&self) -> Result<T, WorkflowUpdateError>where
T: TemporalDeserializable,
Wait for the update to complete and return the result.