WorkflowUpdateWithStartOptions

Struct WorkflowUpdateWithStartOptions 

#[non_exhaustive]
pub struct WorkflowUpdateWithStartOptions {
Show 19 fields pub task_queue: String, pub workflow_id: String, pub id_conflict_policy: WorkflowIdConflictPolicy, pub id_reuse_policy: WorkflowIdReusePolicy, pub execution_timeout: Option<Duration>, pub run_timeout: Option<Duration>, pub task_timeout: Option<Duration>, pub search_attributes: Option<SearchAttributes>, pub retry_policy: Option<RetryPolicy>, pub links: Vec<Link>, pub completion_callbacks: Vec<Callback>, pub priority: Priority, pub start_header: Option<Header>, pub update_header: Option<Header>, pub memo: Option<MemoValues>, pub static_summary: Option<String>, pub static_details: Option<String>, pub update_id: Option<String>, pub rpc_options: RpcOptions,
}
Options for starting a workflow and sending it an update in one atomic operation.

See crate::Client::start_update_with_start_workflow and crate::Client::execute_update_with_start_workflow.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
task_queue: String

The task queue to run the workflow on.

workflow_id: String

The workflow ID.

id_conflict_policy: WorkflowIdConflictPolicy

How to resolve a conflict with an already-running workflow. This is required so callers explicitly choose whether an update may attach to an existing workflow.

id_reuse_policy: WorkflowIdReusePolicy

The policy for reusing the workflow ID after a workflow closes.

execution_timeout: Option<Duration>

The workflow execution timeout.

run_timeout: Option<Duration>

The workflow run timeout.

task_timeout: Option<Duration>

The workflow task timeout.

search_attributes: Option<SearchAttributes>

Search attributes for the workflow.

retry_policy: Option<RetryPolicy>

The workflow retry policy.

links: Vec<Link>

Links to associate with the workflow.

completion_callbacks: Vec<Callback>

Callbacks invoked when the workflow completes.

priority: Priority

Priority for the workflow. Defaults to all-inherited (empty).

start_header: Option<Header>

Headers to include with the start operation.

update_header: Option<Header>

Headers to include with the update operation.

memo: Option<MemoValues>

Non-indexed values attached to the workflow, serialized with the client’s data converter.

static_summary: Option<String>

Single-line static summary for the workflow, shown in the Temporal UI.

static_details: Option<String>

Multi-line static details for the workflow, shown in the Temporal UI.

update_id: Option<String>

Update ID for idempotency. If not provided, a UUID will be generated.

rpc_options: RpcOptions

Controls for the multi-operation RPC and, when executing the update, subsequent polling.

Implementations

Source

impl WorkflowUpdateWithStartOptions

pub fn new( task_queue: impl Into<String>, workflow_id: impl Into<String>, id_conflict_policy: WorkflowIdConflictPolicy, ) -> WorkflowUpdateWithStartOptionsBuilder

Create an instance of WorkflowUpdateWithStartOptions using the builder syntax