WorkflowUpdateWithStartOptionsBuilder

Struct WorkflowUpdateWithStartOptionsBuilder 

pub struct WorkflowUpdateWithStartOptionsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> WorkflowUpdateWithStartOptionsBuilder<S>

pub fn build(self) -> WorkflowUpdateWithStartOptions
where S: IsComplete,

Finish building and return the requested object

pub fn id_reuse_policy( self, value: WorkflowIdReusePolicy, ) -> WorkflowUpdateWithStartOptionsBuilder<SetIdReusePolicy<S>>
where S::IdReusePolicy: IsUnset,

Optional (Some / Option setters). Default: <WorkflowIdReusePolicy as Default>::default().

The policy for reusing the workflow ID after a workflow closes.

pub fn maybe_id_reuse_policy( self, value: Option<WorkflowIdReusePolicy>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetIdReusePolicy<S>>
where S::IdReusePolicy: IsUnset,

Optional (Some / Option setters). Default: <WorkflowIdReusePolicy as Default>::default().

The policy for reusing the workflow ID after a workflow closes.

pub fn execution_timeout( self, value: Duration, ) -> WorkflowUpdateWithStartOptionsBuilder<SetExecutionTimeout<S>>
where S::ExecutionTimeout: IsUnset,

Optional (Some / Option setters). The workflow execution timeout.

pub fn maybe_execution_timeout( self, value: Option<Duration>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetExecutionTimeout<S>>
where S::ExecutionTimeout: IsUnset,

Optional (Some / Option setters). The workflow execution timeout.

pub fn run_timeout( self, value: Duration, ) -> WorkflowUpdateWithStartOptionsBuilder<SetRunTimeout<S>>
where S::RunTimeout: IsUnset,

Optional (Some / Option setters). The workflow run timeout.

pub fn maybe_run_timeout( self, value: Option<Duration>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetRunTimeout<S>>
where S::RunTimeout: IsUnset,

Optional (Some / Option setters). The workflow run timeout.

pub fn task_timeout( self, value: Duration, ) -> WorkflowUpdateWithStartOptionsBuilder<SetTaskTimeout<S>>
where S::TaskTimeout: IsUnset,

Optional (Some / Option setters). The workflow task timeout.

pub fn maybe_task_timeout( self, value: Option<Duration>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetTaskTimeout<S>>
where S::TaskTimeout: IsUnset,

Optional (Some / Option setters). The workflow task timeout.

pub fn search_attributes( self, value: SearchAttributes, ) -> WorkflowUpdateWithStartOptionsBuilder<SetSearchAttributes<S>>
where S::SearchAttributes: IsUnset,

Optional (Some / Option setters). Search attributes for the workflow.

pub fn maybe_search_attributes( self, value: Option<SearchAttributes>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetSearchAttributes<S>>
where S::SearchAttributes: IsUnset,

Optional (Some / Option setters). Search attributes for the workflow.

pub fn retry_policy( self, value: impl Into<RetryPolicy>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetRetryPolicy<S>>
where S::RetryPolicy: IsUnset,

Optional (Some / Option setters). The workflow retry policy.

pub fn maybe_retry_policy( self, value: Option<impl Into<RetryPolicy>>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetRetryPolicy<S>>
where S::RetryPolicy: IsUnset,

Optional (Some / Option setters). The workflow retry policy.

Optional (Some / Option setters). Default: <Vec<common::v1::Link> as Default>::default().

Links to associate with the workflow.

Optional (Some / Option setters). Default: <Vec<common::v1::Link> as Default>::default().

Links to associate with the workflow.

pub fn completion_callbacks( self, value: Vec<Callback>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetCompletionCallbacks<S>>
where S::CompletionCallbacks: IsUnset,

Optional (Some / Option setters). Default: <Vec<common::v1::Callback> as Default>::default().

Callbacks invoked when the workflow completes.

pub fn maybe_completion_callbacks( self, value: Option<Vec<Callback>>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetCompletionCallbacks<S>>
where S::CompletionCallbacks: IsUnset,

Optional (Some / Option setters). Default: <Vec<common::v1::Callback> as Default>::default().

Callbacks invoked when the workflow completes.

pub fn priority( self, value: Priority, ) -> WorkflowUpdateWithStartOptionsBuilder<SetPriority<S>>
where S::Priority: IsUnset,

Optional (Some / Option setters). Default: <Priority as Default>::default().

Priority for the workflow. Defaults to all-inherited (empty).

pub fn maybe_priority( self, value: Option<Priority>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetPriority<S>>
where S::Priority: IsUnset,

Optional (Some / Option setters). Default: <Priority as Default>::default().

Priority for the workflow. Defaults to all-inherited (empty).

pub fn start_header( self, value: Header, ) -> WorkflowUpdateWithStartOptionsBuilder<SetStartHeader<S>>
where S::StartHeader: IsUnset,

Optional (Some / Option setters). Headers to include with the start operation.

pub fn maybe_start_header( self, value: Option<Header>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetStartHeader<S>>
where S::StartHeader: IsUnset,

Optional (Some / Option setters). Headers to include with the start operation.

pub fn update_header( self, value: Header, ) -> WorkflowUpdateWithStartOptionsBuilder<SetUpdateHeader<S>>
where S::UpdateHeader: IsUnset,

Optional (Some / Option setters). Headers to include with the update operation.

pub fn maybe_update_header( self, value: Option<Header>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetUpdateHeader<S>>
where S::UpdateHeader: IsUnset,

Optional (Some / Option setters). Headers to include with the update operation.

pub fn memo( self, value: MemoValues, ) -> WorkflowUpdateWithStartOptionsBuilder<SetMemo<S>>
where S::Memo: IsUnset,

Optional (Some / Option setters). Non-indexed values attached to the workflow, serialized with the client’s data converter.

pub fn maybe_memo( self, value: Option<MemoValues>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetMemo<S>>
where S::Memo: IsUnset,

Optional (Some / Option setters). Non-indexed values attached to the workflow, serialized with the client’s data converter.

pub fn static_summary( self, value: impl Into<String>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetStaticSummary<S>>
where S::StaticSummary: IsUnset,

Optional (Some / Option setters). Single-line static summary for the workflow, shown in the Temporal UI.

pub fn maybe_static_summary( self, value: Option<impl Into<String>>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetStaticSummary<S>>
where S::StaticSummary: IsUnset,

Optional (Some / Option setters). Single-line static summary for the workflow, shown in the Temporal UI.

pub fn static_details( self, value: impl Into<String>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetStaticDetails<S>>
where S::StaticDetails: IsUnset,

Optional (Some / Option setters). Multi-line static details for the workflow, shown in the Temporal UI.

pub fn maybe_static_details( self, value: Option<impl Into<String>>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetStaticDetails<S>>
where S::StaticDetails: IsUnset,

Optional (Some / Option setters). Multi-line static details for the workflow, shown in the Temporal UI.

pub fn update_id( self, value: impl Into<String>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetUpdateId<S>>
where S::UpdateId: IsUnset,

Optional (Some / Option setters). Update ID for idempotency. If not provided, a UUID will be generated.

pub fn maybe_update_id( self, value: Option<impl Into<String>>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetUpdateId<S>>
where S::UpdateId: IsUnset,

Optional (Some / Option setters). Update ID for idempotency. If not provided, a UUID will be generated.

pub fn rpc_options( self, value: RpcOptions, ) -> WorkflowUpdateWithStartOptionsBuilder<SetRpcOptions<S>>
where S::RpcOptions: IsUnset,

Optional (Some / Option setters). Default: <RpcOptions as Default>::default().

Controls for the multi-operation RPC and, when executing the update, subsequent polling.

pub fn maybe_rpc_options( self, value: Option<RpcOptions>, ) -> WorkflowUpdateWithStartOptionsBuilder<SetRpcOptions<S>>
where S::RpcOptions: IsUnset,

Optional (Some / Option setters). Default: <RpcOptions as Default>::default().

Controls for the multi-operation RPC and, when executing the update, subsequent polling.