Module worker

Module worker 

Contains types and logic for interactions between clients and Core/SDK workers

Structs

ClientWorkerSet
Enables local workers to make themselves visible to a shared client instance.

Traits

ClientWorker
Represents a complete worker that can handle both slot management and worker heartbeat functionality.
SharedNamespaceWorkerTrait
This trait represents a shared namespace worker that sends worker heartbeats and receives worker commands.
Slot
This trait represents a slot reserved for processing a WFT by a worker.

Type Aliases

HeartbeatCallback
Contains a worker heartbeat callback, wrapped for mocking