ClientWorkerSet

Struct ClientWorkerSet 

pub struct ClientWorkerSet { /* private fields */ }
Enables local workers to make themselves visible to a shared client instance.

For slot managing, there can only be one worker registered per namespace+queue_name+connection, others will return an error. It also provides a convenient method to find compatible slots within the collection.

Implementations

Source

impl ClientWorkerSet

pub fn new() -> Self

Factory method.

pub fn register_worker( &self, worker: Arc<dyn ClientWorker + Send + Sync>, skip_client_worker_set_check: bool, ) -> Result<(), Error>

Register a local worker that can provide WFT processing slots and potentially worker heartbeating.

pub fn unregister_slot_provider( &self, worker_instance_key: Uuid, ) -> Result<(), Error>

Disables Eager Workflow Start for this worker. This must be called before finalize_unregister, otherwise finalize_unregister will return an err.

pub fn finalize_unregister( &self, worker_instance_key: Uuid, ) -> Result<Arc<dyn ClientWorker + Send + Sync>, Error>

Finalizes unregistering of worker from client. This must be called at the end of worker shutdown in order to finalize shutdown for worker heartbeat properly. Must call after unregister_slot_provider, otherwise an err will be returned.

pub fn worker_grouping_key(&self) -> Uuid

Returns the worker grouping key, which is unique for each worker.