This crate contains client implementations that can be used to contact the Temporal service.
It implements auto-retry behavior and metrics collection.
Re-exports
pub use tonic;
Modules
- callback_
based - This module implements support for callback-based gRPC service that has a callback invoked for every gRPC call instead of directly using the network.
- client_
options_ builder - Tools for manipulating the type state of
ClientOptionsBuilder. - connection_
options_ builder - Tools for manipulating the type state of
ConnectionOptionsBuilder. - errors
- Contains errors that can be returned by clients.
- grpc
- gRPC service traits for direct access to Temporal services.
- request_
extensions - Request extensions for tonic gRPC requests.
- worker
- Contains types and logic for interactions between clients and Core/SDK workers
Structs
- Activity
Heartbeat Response - Response from a heartbeat call.
- Async
Activity Handle - Handle for completing activities asynchronously (outside the worker).
- Client
- Contains an instance of a namespace-bound client for interacting with the Temporal server. Cheap to clone.
- Client
Keep Alive Options - Client keep alive configuration.
- Client
Options - Options for crate::Client::new.
- Client
Options Builder - Use builder syntax to set the inputs and finish with
build(). - Client
TlsOptions - If using mTLS, both the client cert and private key must be specified, this contains them.
- Connection
- A connection to the Temporal service.
- Connection
Options - Options for crate::Connection::connect.
- Connection
Options Builder - Use builder syntax to set the inputs and finish with
build(). - Http
Connect Proxy Options - Options for HTTP CONNECT proxy.
- List
Workflows Stream - A stream of workflow executions from a list query. Internally paginates through results from the server.
- Priority
- Priority contains metadata that controls relative ordering of task processing when tasks are backlogged in a queue. Initially, Priority will be used in activity and workflow task queues, which are typically where backlogs exist. Other queues in the server (such as transfer and timer queues) and rate limiting decisions do not use Priority, but may in the future.
- Register
Namespace Options - Helper struct for
register_namespace. - Register
Namespace Options Builder - Use builder syntax to set the inputs and finish with
build(). - Retry
Options - Configuration for retrying requests to the server
- Service
Call Interceptor - Interceptor which attaches common metadata (like “client-name”) to every outgoing call
- Shared
Replaceable Client - A client wrapper that allows replacing the underlying client at a later point in time. Clones of this struct have a shared reference to the underlying client, and each clone also has its own cached clone of the underlying client. Before every service call, a check is made whether the shared client was replaced, and the cached clone is updated accordingly.
- Temporal
Service Client - Aggregates various services exposed by the Temporal server
- TlsOptions
- Configuration options for TLS
- Untyped
Query - Marker type for sending untyped queries. Stores the query name for runtime lookup.
- Untyped
Signal - Marker type for sending untyped signals. Stores the signal name for runtime lookup.
- Untyped
Update - Marker type for sending untyped updates. Stores the update name for runtime lookup.
- Untyped
Workflow - Marker type for untyped workflow handles. Stores the workflow type name.
- Workflow
Cancel Options - Options for cancelling a workflow.
- Workflow
Cancel Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Count Aggregation Group - Aggregation group from a workflow count query with a group-by clause.
- Workflow
Count Options - Options for counting workflows.
- Workflow
Count Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Describe Options - Options for describing a workflow.
- Workflow
Describe Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Execute Update Options - Options for starting a workflow update.
- Workflow
Execute Update Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Execution - A workflow execution returned from list operations. This represents information about a workflow present in visibility.
- Workflow
Execution Count - Result of a workflow count operation.
- Workflow
Execution Description - Description of a workflow execution returned by
WorkflowHandle::describe. - Workflow
Execution Info - Holds needed information to refer to a specific workflow run, or workflow execution chain
- Workflow
Fetch History Options - Options for fetching workflow history.
- Workflow
Fetch History Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
GetResult Options - Options for fetching workflow results
- Workflow
GetResult Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Handle - A workflow handle which can refer to a specific workflow run, or a chain of workflow runs with the same workflow id.
- Workflow
History - Workflow execution history returned by
WorkflowHandle::fetch_history. - Workflow
List Options - Options for listing workflows.
- Workflow
List Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Query Options - Options for querying a workflow.
- Workflow
Query Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Signal Options - Options for sending a signal to a workflow.
- Workflow
Signal Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Start Options - Options for starting a workflow execution.
- Workflow
Start Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Start Signal - A signal to send atomically when starting a workflow.
Use with
WorkflowStartOptions::start_signalto achieve signal-with-start behavior. - Workflow
Start Signal Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Start Update Options - Options for starting an update without waiting for completion.
- Workflow
Start Update Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Terminate Options - Options for terminating a workflow.
- Workflow
Terminate Options Builder - Use builder syntax to set the inputs and finish with
build(). - Workflow
Update Handle - Handle to a workflow update that has been started but may not be complete.
Enums
- Activity
Identifier - Identifies an async activity for completion outside a worker.
- Namespace
- Enum to help reference a namespace by either the namespace name or the namespace id
- Workflow
Execution Result - Enumerates terminal states for a particular workflow execution
- Workflow
Update Wait Stage - Which lifecycle stage to wait for when starting an update.
Statics
- LONG_
REQUEST_ LATENCY_ HISTOGRAM_ NAME - The string name (which may be prefixed) for this metric
- REQUEST_
LATENCY_ HISTOGRAM_ NAME - The string name (which may be prefixed) for this metric
Traits
- Namespaced
Client - A client that is bound to a namespace
Type Aliases
- Untyped
Workflow Handle - A workflow handle to a workflow with unknown types. Uses single argument raw payloads for input and output.