This module implements support for callback-based gRPC service that has a callback invoked for every gRPC call instead of directly using the network.
Structs
- Callback
Based Grpc Service - gRPC service that invokes the given callback on each call.
- Grpc
Request - gRPC request for use by a callback.
- Grpc
Success Response - Successful gRPC response returned by a callback.