Trait State Copy item path Source pub trait State: Sized {
Show 15 associated items type Identity ;
type MetricsMeter ;
type TlsOptions ;
type OverrideOrigin ;
type ApiKey ;
type RetryOptions ;
type KeepAlive ;
type Headers ;
type BinaryHeaders ;
type HttpConnectProxy ;
type DisableErrorCodeMetricTags ;
type ServiceOverride ;
type SkipGetSystemInfo ;
type ClientName ;
type ClientVersion ;
}Expand description Builder’s type state specifies if members are set or not (unset).
You can use the associated types of this trait to control the state of individual members with the IsSet and IsUnset traits. You can change the state of the members with the Set* structs available in this module.
Type state of the member identity.
It can implement either IsSet or IsUnset
Type state of the member metrics_meter.
It can implement either IsSet or IsUnset
Type state of the member tls_options.
It can implement either IsSet or IsUnset
Type state of the member override_origin.
It can implement either IsSet or IsUnset
Type state of the member api_key.
It can implement either IsSet or IsUnset
Type state of the member retry_options.
It can implement either IsSet or IsUnset
Type state of the member keep_alive.
It can implement either IsSet or IsUnset
Type state of the member headers.
It can implement either IsSet or IsUnset
Type state of the member binary_headers.
It can implement either IsSet or IsUnset
Type state of the member http_connect_proxy.
It can implement either IsSet or IsUnset
Type state of the member disable_error_code_metric_tags.
It can implement either IsSet or IsUnset
Type state of the member service_override.
It can implement either IsSet or IsUnset
Type state of the member skip_get_system_info.
It can implement either IsSet or IsUnset
Type state of the member client_name.
It can implement either IsSet or IsUnset
Type state of the member client_version.
It can implement either IsSet or IsUnset
This trait is not dyn compatible .
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.