Potentially dangerous TLS related functionality.
Traits
- Server
Cert Verifier - Re-export the
ServerCertVerifiertrait so that users can implement custom TLS server certificate verification without depending ontokio-rustlsdirectly, while explicitly acknowledging the danger in the import path. Something that can verify a server certificate chain, and verify signatures made by certificates.