#[non_exhaustive]pub enum VersioningOverride {
Pinned(WorkerDeploymentVersion),
AutoUpgrade,
OneTime(WorkerDeploymentVersion),
}Expand description
Overrides a workflow’s worker deployment routing.
Experimental: Pinned and auto-upgrade overrides for client-started workflows require Temporal Server 1.28.0 or later. Child workflow overrides require Temporal Server 1.32.0 or later.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pinned(WorkerDeploymentVersion)
Keep routing the workflow to this deployment version until the override is removed.
AutoUpgrade
Route the workflow using the task queue’s current deployment version.
OneTime(WorkerDeploymentVersion)
Route to this version until one workflow task completes there, then use the versioning behavior and deployment version reported by that worker.
Requires Temporal Server 1.32.0 or later.