pub struct ClientConfigProfile {
pub address: Option<String>,
pub namespace: Option<String>,
pub api_key: Option<String>,
pub tls: Option<ClientConfigTLS>,
pub codec: Option<ClientConfigCodec>,
pub grpc_meta: HashMap<String, String>,
}Expand description
ClientConfigProfile is profile-level configuration for a client.
Fields
address: Option<String>Client address
namespace: Option<String>Client namespace
api_key: Option<String>Client API key. If present and TLS field is None or present and not disabled (i.e. without Disabled as true), TLS is defaulted to enabled.
tls: Option<ClientConfigTLS>Optional client TLS config.
codec: Option<ClientConfigCodec>Optional client codec config.
grpc_meta: HashMap<String, String>Client gRPC metadata (aka headers). When loading from TOML and env var, or writing to TOML, the keys are lowercased and underscores are replaced with hyphens. This is used for deduplicating/overriding too, so manually set values that are not normalized may not get overridden when applying environment variables.
Implementations
Sourceimpl ClientConfigProfile
impl ClientConfigProfile
Sourcepub fn load_from_env(
&mut self,
env_vars: Option<&HashMap<String, String>>,
) -> Result<(), ConfigError>
pub fn load_from_env( &mut self, env_vars: Option<&HashMap<String, String>>, ) -> Result<(), ConfigError>
Apply environment variable overrides to this profile.
If env_vars is None, the system’s environment variables will be used as the source.