pub struct LoadClientConfigProfileOptions {
pub config_source: Option<DataSource>,
pub config_file_profile: Option<String>,
pub config_file_strict: bool,
pub disable_file: bool,
pub disable_env: bool,
}Expand description
Options for loading a client configuration profile
Fields
config_source: Option<DataSource>Where to load config from. If unset, will try env vars then default path.
config_file_profile: Option<String>Specific profile to use
config_file_strict: boolIf true, will error if there are unrecognized keys.
disable_file: boolDisable loading from file
disable_env: boolDisable loading from environment variables