Contains errors that can be returned by clients.
Enums
- Async
Activity Error - Errors that can occur when completing an activity asynchronously.
- Client
Connect Error - Errors thrown while attempting to establish a connection to the server
- Client
Error - Errors returned by client methods that don’t need more specific error types.
- Client
NewError - Errors that can occur when constructing a
crate::Client. - Invalid
Header Error - Errors thrown when a gRPC metadata header is invalid.
- Workflow
GetResult Error - Errors returned by workflow get_result operations.
- Workflow
Interaction Error - Errors returned by methods on crate::WorkflowHandle for general operations like signal, cancel, terminate, describe, fetch_history, and get_result.
- Workflow
Query Error - Errors returned by query operations on crate::WorkflowHandle.
- Workflow
Start Error - Errors that can occur when starting a workflow.
- Workflow
Update Error - Errors returned by update operations on crate::WorkflowHandle.