gRPC service traits for direct access to Temporal services.
Most users should use the higher-level methods on Client or Connection instead.
These traits are useful for advanced scenarios like custom interceptors, testing with mocks,
or making raw gRPC calls not covered by the higher-level API.
Traits
- Cloud
Service - Trait version of CloudServiceClient
- Health
Service - Trait version of HealthClient
- Operator
Service - Trait version of OperatorServiceClient
- Test
Service - Trait version of TestServiceClient
- Workflow
Service - Trait version of WorkflowServiceClient