Interceptors for high-level client operations. Interceptors for high-level client operations.
Structs
- Backfill
Schedule Input - Input to
ClientInterceptor::backfill_schedule. - Cancel
Workflow Input - Input to
ClientInterceptor::cancel_workflow. - Complete
Async Activity Input - Input to
ClientInterceptor::complete_async_activity. - Count
Workflows Input - Input to
ClientInterceptor::count_workflows. - Count
Workflows Output - Result of an intercepted workflow count.
- Create
Schedule Input - Input to
ClientInterceptor::create_schedule. - Create
Schedule Output - Result of an intercepted schedule create.
- Delete
Schedule Input - Input to
ClientInterceptor::delete_schedule. - Describe
Schedule Input - Input to
ClientInterceptor::describe_schedule. - Describe
Schedule Output - Result of an intercepted schedule describe.
- Describe
Workflow Input - Input to
ClientInterceptor::describe_workflow. - Describe
Workflow Output - Result of an intercepted workflow describe.
- Fail
Async Activity Input - Input to
ClientInterceptor::fail_async_activity. - Fetch
Workflow History Page Input - Input to
ClientInterceptor::fetch_workflow_history_page. - Fetch
Workflow History Page Output - Result of one intercepted workflow-history page.
- Heartbeat
Async Activity Input - Input to
ClientInterceptor::heartbeat_async_activity. - List
Schedules Page Input - Input to
ClientInterceptor::list_schedules_page. - List
Schedules Page Output - Result of one intercepted schedule-list page.
- List
Workflows Page Input - Input to
ClientInterceptor::list_workflows_page. - List
Workflows Page Output - Result of one intercepted workflow-list page.
- Next
- Continuation for an intercepted client operation.
- Pause
Schedule Input - Input to
ClientInterceptor::pause_schedule. - Poll
Workflow Update Input - Input to
ClientInterceptor::poll_workflow_update. - Poll
Workflow Update Output - Result of an intercepted workflow-update poll.
- Query
Workflow Input - Input to
ClientInterceptor::query_workflow. - Query
Workflow Output - Result of an intercepted workflow query before typed result conversion.
- Report
Async Activity Cancellation Input - Input to
ClientInterceptor::report_async_activity_cancellation. - Send
Schedule Update Input - Input to
ClientInterceptor::send_schedule_update. - Signal
Workflow Input - Input to
ClientInterceptor::signal_workflow. - Start
Workflow Input - Input to
ClientInterceptor::start_workflow. - Start
Workflow Output - Result of a successful intercepted workflow start.
- Start
Workflow Update Input - Input to
ClientInterceptor::start_workflow_update. - Start
Workflow Update Output - Result of an intercepted workflow-update start.
- Terminate
Workflow Input - Input to
ClientInterceptor::terminate_workflow. - Trigger
Schedule Input - Input to
ClientInterceptor::trigger_schedule. - Unpause
Schedule Input - Input to
ClientInterceptor::unpause_schedule. - Update
Schedule Input - Input to
ClientInterceptor::update_schedule.
Traits
- Client
Interceptor - Intercepts high-level client operations.
- HasArgs
- Provides access to the arguments carried by a client interceptor input.
- Temporal
Client Value - Type-erased input carried through the client interceptor chain.