#[non_exhaustive]pub struct PluginApplyError {
pub plugin_name: String,
pub target: PluginTarget,
pub source: PluginError,
}Expand description
An error applying a named plugin to a configuration target.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.plugin_name: StringThe plugin name reported by ClientPlugin::name or its worker equivalent.
target: PluginTargetThe configuration target being modified.
source: PluginErrorThe error returned by the plugin.
Implementations
Sourceimpl PluginApplyError
impl PluginApplyError
Sourcepub fn new(
plugin_name: impl Into<String>,
target: PluginTarget,
source: PluginError,
) -> Self
pub fn new( plugin_name: impl Into<String>, target: PluginTarget, source: PluginError, ) -> Self
Create an error for a plugin that failed to configure a target.
Internal: This method is intended to be used during worker construction. Arguments can change or be removed in breaking manners.