Request extensions for tonic gRPC requests.
These types can be inserted into tonic request extensions to modify behavior of retires or other request handling logic.
Structs
- IsWorker
Task Long Poll - A request extension that, when set, should make the retry behavior consider this call to be a CallType::TaskLongPoll
- NoRetry
OnMatching - A request extension that, when set, and a call is being processed by a retrying client, allows the caller to request certain matching errors to short-circuit-return immediately and not follow normal retry logic.
- Retry
Config ForCall - A request extension that forces overriding the current retry policy of the crate::Connection.
Traits
- Request
Ext - Extension trait for tonic requests to set default timeouts