pub struct ScheduleSpec {
pub intervals: Vec<ScheduleIntervalSpec>,
pub calendars: Vec<ScheduleCalendarSpec>,
pub exclude_calendars: Vec<ScheduleCalendarSpec>,
pub cron_strings: Vec<String>,
pub timezone_name: String,
pub start_time: Option<SystemTime>,
pub end_time: Option<SystemTime>,
pub jitter: Option<Duration>,
}Expand description
Defines when a schedule should trigger.
Note: set_spec on ScheduleUpdate replaces the entire spec. Fields not
set here will use their proto defaults on the server.
Fields
intervals: Vec<ScheduleIntervalSpec>Interval-based triggers (e.g., every 1 hour).
calendars: Vec<ScheduleCalendarSpec>Calendar-based triggers using range strings.
exclude_calendars: Vec<ScheduleCalendarSpec>Calendar-based exclusions. Matching times are skipped.
cron_strings: Vec<String>Cron expression triggers (e.g., "0 12 * * MON-FRI").
timezone_name: StringIANA timezone name (e.g., "US/Eastern"). Empty uses UTC.
start_time: Option<SystemTime>Earliest time the schedule is active.
end_time: Option<SystemTime>Latest time the schedule is active.
jitter: Option<Duration>Random jitter applied to each action time.
Implementations
Sourceimpl ScheduleSpec
impl ScheduleSpec
Sourcepub fn builder() -> ScheduleSpecBuilder
pub fn builder() -> ScheduleSpecBuilder
Create an instance of ScheduleSpec using the builder syntax
Sourceimpl ScheduleSpec
impl ScheduleSpec
Sourcepub fn from_interval(every: Duration) -> Self
pub fn from_interval(every: Duration) -> Self
Create a spec that triggers on a single interval.
Sourcepub fn from_calendar(calendar: ScheduleCalendarSpec) -> Self
pub fn from_calendar(calendar: ScheduleCalendarSpec) -> Self
Create a spec that triggers on a single calendar schedule.