pub struct Client { /* private fields */ }Expand description
Contains an instance of a namespace-bound client for interacting with the Temporal server. Cheap to clone.
Implementations
Sourceimpl Client
impl Client
Sourcepub async fn create_schedule(
&self,
schedule_id: impl Into<String>,
opts: CreateScheduleOptions,
) -> Result<ScheduleHandle<Self>, ScheduleError>
pub async fn create_schedule( &self, schedule_id: impl Into<String>, opts: CreateScheduleOptions, ) -> Result<ScheduleHandle<Self>, ScheduleError>
Create a schedule and return a handle to it.
Sourcepub fn get_schedule_handle(
&self,
schedule_id: impl Into<String>,
) -> ScheduleHandle<Self>
pub fn get_schedule_handle( &self, schedule_id: impl Into<String>, ) -> ScheduleHandle<Self>
Get a handle to an existing schedule by ID.
Sourcepub fn list_schedules(&self, opts: ListSchedulesOptions) -> ListSchedulesStream
pub fn list_schedules(&self, opts: ListSchedulesOptions) -> ListSchedulesStream
List schedules matching the query, returning a stream that lazily paginates through results.
Sourceimpl Client
impl Client
Sourcepub async fn connect(
connection_options: ConnectionOptions,
client_options: ClientOptions,
) -> Result<Self, ClientConnectError>
pub async fn connect( connection_options: ConnectionOptions, client_options: ClientOptions, ) -> Result<Self, ClientConnectError>
Connect to a Temporal service and create a namespace-bound client, applying registered plugins to connection and client options in registration order.
Sourcepub fn new(
connection: Connection,
options: ClientOptions,
) -> Result<Self, ClientNewError>
pub fn new( connection: Connection, options: ClientOptions, ) -> Result<Self, ClientNewError>
Create a new client from a connection and options.
Registered client plugins are applied here. Connection plugin hooks only run when using
Client::connect.
Sourcepub fn options(&self) -> &ClientOptions
pub fn options(&self) -> &ClientOptions
Return the options this client was initialized with
Sourcepub fn options_mut(&mut self) -> &mut ClientOptions
pub fn options_mut(&mut self) -> &mut ClientOptions
Return this client’s options mutably.
Note: If this client has been cloned, this will copy-on-write to avoid affecting other clones.
Sourcepub fn connection(&self) -> &Connection
pub fn connection(&self) -> &Connection
Returns a reference to the underlying connection
Sourcepub fn connection_mut(&mut self) -> &mut Connection
pub fn connection_mut(&mut self) -> &mut Connection
Returns a mutable reference to the underlying connection
Sourceimpl Client
impl Client
Sourcepub async fn start_workflow<W>(
&self,
workflow: W,
input: W::Input,
options: WorkflowStartOptions,
) -> Result<WorkflowHandle<Self, W>, WorkflowStartError>
pub async fn start_workflow<W>( &self, workflow: W, input: W::Input, options: WorkflowStartOptions, ) -> Result<WorkflowHandle<Self, W>, WorkflowStartError>
Start a workflow execution.
Returns a WorkflowHandle that can be used to interact with the workflow
(e.g., get its result, send signals, query, etc.).
Sourcepub fn get_workflow_handle<W: HasWorkflowDefinition>(
&self,
workflow_id: impl Into<String>,
) -> WorkflowHandle<Self, W>
pub fn get_workflow_handle<W: HasWorkflowDefinition>( &self, workflow_id: impl Into<String>, ) -> WorkflowHandle<Self, W>
Get a handle to an existing workflow.
For untyped access, use get_workflow_handle::<UntypedWorkflow>(...).
Sourcepub fn list_workflows(
&self,
query: impl Into<String>,
opts: WorkflowListOptions,
) -> ListWorkflowsStream
pub fn list_workflows( &self, query: impl Into<String>, opts: WorkflowListOptions, ) -> ListWorkflowsStream
List workflows matching a query.
Returns a stream that lazily paginates through results.
Use limit in options to cap the number of results returned.
Sourcepub async fn count_workflows(
&self,
query: impl Into<String>,
opts: WorkflowCountOptions,
) -> Result<WorkflowExecutionCount, ClientError>
pub async fn count_workflows( &self, query: impl Into<String>, opts: WorkflowCountOptions, ) -> Result<WorkflowExecutionCount, ClientError>
Count workflows matching a query.
Sourcepub fn get_async_activity_handle(
&self,
identifier: ActivityIdentifier,
) -> AsyncActivityHandle<Self>
pub fn get_async_activity_handle( &self, identifier: ActivityIdentifier, ) -> AsyncActivityHandle<Self>
Get a handle to complete an activity asynchronously.
An activity returning ActivityError::WillCompleteAsync can be completed with this handle.
To get a handle to a standalone activity that can be used to wait for result and manage
the execution, see get_activity_handle.
Sourcepub async fn start_activity<A>(
&self,
activity: A,
input: A::Input,
options: ActivityStartOptions,
) -> Result<ActivityHandle<Self, A>, StartActivityError>where
A: ActivityDefinition,
pub async fn start_activity<A>(
&self,
activity: A,
input: A::Input,
options: ActivityStartOptions,
) -> Result<ActivityHandle<Self, A>, StartActivityError>where
A: ActivityDefinition,
Start a standalone activity.
Returns ActivityHandle that can be used to wait for result or to perform other
operations on the activity.
Sourcepub fn get_activity_handle<A>(
&self,
activity: A,
id: impl Into<String>,
run_id: Option<String>,
) -> ActivityHandle<Self, A>where
Self: Sized,
A: ActivityDefinition,
pub fn get_activity_handle<A>(
&self,
activity: A,
id: impl Into<String>,
run_id: Option<String>,
) -> ActivityHandle<Self, A>where
Self: Sized,
A: ActivityDefinition,
Get a handle to an existing standalone activity execution. If run_id is not specified,
the handle always targets the latest execution with matching ID.
Note that the validity of the handle is not checked until a method is called on it.
If invalid ID or run ID is used, the method will return NotFound error.
To get an untyped handle, use get_untyped_activity_handle.
To get a handle that can be used to complete an activity asynchronously,
see get_async_activity_handle.
Sourcepub fn get_untyped_activity_handle(
&self,
id: impl Into<String>,
run_id: Option<String>,
) -> ActivityHandle<Self, UntypedActivity>where
Self: Sized,
pub fn get_untyped_activity_handle(
&self,
id: impl Into<String>,
run_id: Option<String>,
) -> ActivityHandle<Self, UntypedActivity>where
Self: Sized,
Get an untyped handle to an existing standalone activity execution. If run_id is not
specified, the handle always targets the latest execution with matching ID.
Note that the validity of the handle is not checked until a method is called on it.
If invalid ID or run ID is used, the method will return NotFound error.
To get a typed handle, use get_activity_handle.
To get a handle that can be used to complete an activity asynchronously,
see get_async_activity_handle.
Sourcepub fn list_activities(
&self,
query: impl Into<String>,
options: ActivityListOptions,
) -> ListActivitiesStream
pub fn list_activities( &self, query: impl Into<String>, options: ActivityListOptions, ) -> ListActivitiesStream
List activities matching a query. Returns a stream that lazily paginates through results.
Sourcepub async fn count_activities(
&self,
query: impl Into<String>,
options: ActivityCountOptions,
) -> Result<ActivityExecutionCount, ClientError>
pub async fn count_activities( &self, query: impl Into<String>, options: ActivityCountOptions, ) -> Result<ActivityExecutionCount, ClientError>
Count activities matching a query.