pub struct Connection { /* private fields */ }Expand description
A connection to the Temporal service.
Cloning a connection is cheap (single Arc increment). The underlying connection is shared between clones.
Implementations
Sourceimpl Connection
impl Connection
Sourcepub async fn connect(
options: ConnectionOptions,
) -> Result<Self, ClientConnectError>
pub async fn connect( options: ConnectionOptions, ) -> Result<Self, ClientConnectError>
Connect to a Temporal service.
Sourcepub fn set_api_key(&self, api_key: Option<String>)
pub fn set_api_key(&self, api_key: Option<String>)
Set API key, overwriting any previous one.
Sourcepub fn set_headers(
&self,
headers: HashMap<String, String>,
) -> Result<(), InvalidHeaderError>
pub fn set_headers( &self, headers: HashMap<String, String>, ) -> Result<(), InvalidHeaderError>
Set HTTP request headers overwriting previous headers.
This will not affect headers set via ConnectionOptions::binary_headers.
Errors
Will return an error if any of the provided keys or values are not valid gRPC metadata. If an error is returned, the previous headers will remain unchanged.
Sourcepub fn set_binary_headers(
&self,
binary_headers: HashMap<String, Vec<u8>>,
) -> Result<(), InvalidHeaderError>
pub fn set_binary_headers( &self, binary_headers: HashMap<String, Vec<u8>>, ) -> Result<(), InvalidHeaderError>
Set binary HTTP request headers overwriting previous headers.
This will not affect headers set via ConnectionOptions::headers.
Errors
Will return an error if any of the provided keys are not valid gRPC binary metadata keys. If an error is returned, the previous headers will remain unchanged.
Sourcepub fn client_name(&self) -> &str
pub fn client_name(&self) -> &str
Returns the value used for the client-name header by this connection.
Sourcepub fn client_version(&self) -> &str
pub fn client_version(&self) -> &str
Returns the value used for the client-version header by this connection.
Sourcepub fn capabilities(&self) -> Option<&Capabilities>
pub fn capabilities(&self) -> Option<&Capabilities>
Returns the server capabilities we (may have) learned about when establishing an initial connection
Sourcepub fn retry_options_mut(&mut self) -> &mut RetryOptions
pub fn retry_options_mut(&mut self) -> &mut RetryOptions
Get a mutable reference to the retry options.
Note: If this connection has been cloned, this will copy-on-write to avoid affecting other clones.
Sourcepub fn identity_mut(&mut self) -> &mut String
pub fn identity_mut(&mut self) -> &mut String
Get a mutable reference to the connection identity.
Note: If this connection has been cloned, this will copy-on-write to avoid affecting other clones.
Sourcepub fn workers(&self) -> Arc<ClientWorkerSet>
pub fn workers(&self) -> Arc<ClientWorkerSet>
Returns a reference to a registry with workers using this client instance.
Sourcepub fn worker_grouping_key(&self) -> Uuid
pub fn worker_grouping_key(&self) -> Uuid
Returns the client-wide key.
Sourcepub fn workflow_service(&self) -> Box<dyn WorkflowService>
pub fn workflow_service(&self) -> Box<dyn WorkflowService>
Get the underlying workflow service client for making raw gRPC calls.
Sourcepub fn operator_service(&self) -> Box<dyn OperatorService>
pub fn operator_service(&self) -> Box<dyn OperatorService>
Get the underlying operator service client for making raw gRPC calls.
Sourcepub fn cloud_service(&self) -> Box<dyn CloudService>
pub fn cloud_service(&self) -> Box<dyn CloudService>
Get the underlying cloud service client for making raw gRPC calls.
Sourcepub fn test_service(&self) -> Box<dyn TestService>
pub fn test_service(&self) -> Box<dyn TestService>
Get the underlying test service client for making raw gRPC calls.
Sourcepub fn health_service(&self) -> Box<dyn HealthService>
pub fn health_service(&self) -> Box<dyn HealthService>
Get the underlying health service client for making raw gRPC calls.