#[non_exhaustive]pub struct Memo { /* private fields */ }Expand description
A collection of memo payloads that can be deserialized into typed values.
Implementations
Sourceimpl Memo
impl Memo
Sourcepub fn get<T>(&self, key: &str) -> Result<Option<T>, PayloadConversionError>where
T: TemporalDeserializable + 'static,
pub fn get<T>(&self, key: &str) -> Result<Option<T>, PayloadConversionError>where
T: TemporalDeserializable + 'static,
Decode a memo value as T, returning None when the key is absent.
Sourcepub fn contains_key(&self, key: &str) -> bool
pub fn contains_key(&self, key: &str) -> bool
Returns whether the memo contains key.