pub struct TlsOptions {
pub server_root_ca_cert: Option<Vec<u8>>,
pub domain: Option<String>,
pub client_tls_options: Option<ClientTlsOptions>,
}Expand description
Configuration options for TLS
Fields
server_root_ca_cert: Option<Vec<u8>>Bytes representing the root CA certificate used by the server. If not set, and the server’s cert is issued by someone the operating system trusts, verification will still work (ex: Cloud offering).
domain: Option<String>Sets the domain name against which to verify the server’s TLS certificate. If not provided, the domain name will be extracted from the URL used to connect.
client_tls_options: Option<ClientTlsOptions>TLS info for the client. If specified, core will attempt to use mTLS.