pub struct WorkflowExecution { /* private fields */ }Expand description
A workflow execution returned from list operations. This represents information about a workflow present in visibility.
Implementations
Sourceimpl WorkflowExecution
impl WorkflowExecution
Sourcepub fn new(raw: WorkflowExecutionInfo) -> Self
pub fn new(raw: WorkflowExecutionInfo) -> Self
Create a new WorkflowExecution from the raw proto.
Sourcepub fn workflow_type(&self) -> &str
pub fn workflow_type(&self) -> &str
The workflow type name.
Sourcepub fn status(&self) -> WorkflowExecutionStatus
pub fn status(&self) -> WorkflowExecutionStatus
The current status of the workflow execution.
Sourcepub fn start_time(&self) -> Option<SystemTime>
pub fn start_time(&self) -> Option<SystemTime>
When the workflow was created.
Sourcepub fn execution_time(&self) -> Option<SystemTime>
pub fn execution_time(&self) -> Option<SystemTime>
When the workflow run started or should start.
Sourcepub fn close_time(&self) -> Option<SystemTime>
pub fn close_time(&self) -> Option<SystemTime>
When the workflow was closed, if closed.
Sourcepub fn task_queue(&self) -> &str
pub fn task_queue(&self) -> &str
The task queue the workflow runs on.
Sourcepub fn history_length(&self) -> i64
pub fn history_length(&self) -> i64
Number of events in history.
Sourcepub fn parent_run_id(&self) -> Option<&str>
pub fn parent_run_id(&self) -> Option<&str>
Parent run ID, if this is a child workflow.
Sourcepub fn search_attributes(&self) -> Option<&SearchAttributes>
pub fn search_attributes(&self) -> Option<&SearchAttributes>
Search attributes on the workflow.
Sourcepub fn raw(&self) -> &WorkflowExecutionInfo
pub fn raw(&self) -> &WorkflowExecutionInfo
Access the raw proto for additional fields not exposed via accessors.
Sourcepub fn into_raw(self) -> WorkflowExecutionInfo
pub fn into_raw(self) -> WorkflowExecutionInfo
Consume the wrapper and return the raw proto.