pub struct WorkflowExecutionInfo {
pub namespace: String,
pub workflow_id: String,
pub run_id: Option<String>,
pub first_execution_run_id: Option<String>,
}Expand description
Holds needed information to refer to a specific workflow run, or workflow execution chain
Fields
namespace: StringNamespace the workflow lives in.
workflow_id: StringThe workflow’s id.
run_id: Option<String>If set, target this specific run of the workflow.
first_execution_run_id: Option<String>Run ID used for cancellation and termination to ensure they happen on a workflow starting with this run ID. This can be set when getting a workflow handle. When starting a workflow, this is set as the resulting run ID if no start signal was provided.
Implementations
Sourceimpl WorkflowExecutionInfo
impl WorkflowExecutionInfo
Sourcepub fn bind_untyped<CT>(self, client: CT) -> UntypedWorkflowHandle<CT>where
CT: WorkflowService + Clone,
pub fn bind_untyped<CT>(self, client: CT) -> UntypedWorkflowHandle<CT>where
CT: WorkflowService + Clone,
Bind the workflow info to a specific client, turning it into a workflow handle