#[non_exhaustive]pub struct WorkflowResultDetails { /* private fields */ }Expand description
Details attached to a cancelled or terminated workflow result.
Implementations
Sourceimpl WorkflowResultDetails
impl WorkflowResultDetails
Sourcepub fn deserialize<T: TemporalDeserializable + 'static>(
&self,
) -> Result<T, PayloadConversionError>
pub fn deserialize<T: TemporalDeserializable + 'static>( &self, ) -> Result<T, PayloadConversionError>
Deserialize the details into a typed value using the client’s payload converter.