pub trait ActivityExecutionInfoLike {
// Required methods
fn activity_id(&self) -> &str;
fn activity_run_id(&self) -> &str;
fn activity_type(&self) -> &str;
fn schedule_time(&self) -> Option<SystemTime>;
fn close_time(&self) -> Option<SystemTime>;
fn status(&self) -> ActivityExecutionStatus;
fn task_queue(&self) -> &str;
fn execution_duration(&self) -> Option<Duration>;
}Expand description
Common methods of ActivityExecutionInfo and ActivityExecutionDescription.
Required Methods
Sourcefn activity_id(&self) -> &str
fn activity_id(&self) -> &str
ID of the activity.
Sourcefn activity_run_id(&self) -> &str
fn activity_run_id(&self) -> &str
Run ID of a particular execution of the activity.
Sourcefn activity_type(&self) -> &str
fn activity_type(&self) -> &str
Type of the activity.
Sourcefn schedule_time(&self) -> Option<SystemTime>
fn schedule_time(&self) -> Option<SystemTime>
Time the activity was originally scheduled.
Sourcefn close_time(&self) -> Option<SystemTime>
fn close_time(&self) -> Option<SystemTime>
Time when the activity transitioned to a closed state.
Sourcefn status(&self) -> ActivityExecutionStatus
fn status(&self) -> ActivityExecutionStatus
A general status for this activity, indicates whether it is currently running or in one of the terminal statuses.
Sourcefn task_queue(&self) -> &str
fn task_queue(&self) -> &str
The task queue this activity was scheduled on.
Sourcefn execution_duration(&self) -> Option<Duration>
fn execution_duration(&self) -> Option<Duration>
The difference between close time and scheduled time. This field is only populated if the activity is closed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".