Contains types and logic for interactions between clients and Core/SDK workers
Structs
- Client
Worker Set - Enables local workers to make themselves visible to a shared client instance.
Traits
- Client
Worker - Represents a complete worker that can handle both slot management and worker heartbeat functionality.
- Shared
Namespace Worker Trait - This trait represents a shared namespace worker that sends worker heartbeats and receives worker commands.
- Slot
- This trait represents a slot reserved for processing a WFT by a worker.
Type Aliases
- Heartbeat
Callback - Contains a worker heartbeat callback, wrapped for mocking