SharedNamespaceWorkerTrait

Trait SharedNamespaceWorkerTrait 

pub trait SharedNamespaceWorkerTrait {
    // Required methods
    fn namespace(&self) -> String;
    fn register_callback(
        &self,
        worker_instance_key: Uuid,
        heartbeat_callback: HeartbeatCallback,
    );
    fn unregister_callback(
        &self,
        worker_instance_key: Uuid,
    ) -> (Option<HeartbeatCallback>, bool);
    fn num_workers(&self) -> usize;
}
This trait represents a shared namespace worker that sends worker heartbeats and receives worker commands.

Required Methods

fn namespace(&self) -> String

Namespace that the shared namespace worker is connected to.

fn register_callback( &self, worker_instance_key: Uuid, heartbeat_callback: HeartbeatCallback, )

Registers a heartbeat callback.

fn unregister_callback( &self, worker_instance_key: Uuid, ) -> (Option<HeartbeatCallback>, bool)

Unregisters a heartbeat callback. Returns the callback removed, as well as a bool that indicates if there are no remaining callbacks in the SharedNamespaceWorker, indicating the shared worker itself can be shut down.

fn num_workers(&self) -> usize

Returns the number of workers registered to this shared worker.

Implementors